@@ -1,9 +1,9 @@
 //! `NcCell` methods and associated functions.
 
 use crate::{
-    c_api::{self, nccell_load},
-    cstring, error, rstring, NcAlpha, NcCell, NcChannels, NcComponent, NcError, NcIntResult,
-    NcIntResultApi, NcPaletteIndex, NcPlane, NcResult, NcRgb, NcStyle,
+    c_api::{self, nccell_load, NcChannels_u64, NCRESULT_ERR},
+    cstring, error, rstring, NcAlpha, NcCell, NcChannels, NcError, NcPaletteIndex, NcPlane,
+    NcResult, NcRgb, NcStyle,
 };
 
 #[allow(unused_imports)] // for doc comments
@@ -22,8 +22,8 @@ impl NcCell {
             gcluster: (ch as u32).to_le(),
             gcluster_backstop: 0,
             width: 0_u8,
-            stylemask: 0 as NcStyle,
-            channels: 0 as NcChannels,
+            stylemask: NcStyle::None.into(),
+            channels: 0 as NcChannels_u64,
         })
     }
 
@@ -34,7 +34,7 @@ impl NcCell {
     pub fn from_char(plane: &mut NcPlane, ch: char) -> NcResult<Self> {
         let mut cell = Self::new();
         let res = unsafe { nccell_load(plane, &mut cell, cstring![ch.to_string()]) };
-        if res == NcIntResult::ERR {
+        if res == NCRESULT_ERR {
             return Err(NcError::new());
         }
         Ok(cell)
@@ -47,7 +47,7 @@ impl NcCell {
     pub fn from_str(plane: &mut NcPlane, string: &str) -> NcResult<Self> {
         let mut cell = Self::new();
         let res = unsafe { nccell_load(plane, &mut cell, cstring![string]) };
-        if res == NcIntResult::ERR {
+        if res == NCRESULT_ERR {
             return Err(NcError::new());
         }
         Ok(cell)
@@ -89,7 +89,7 @@ impl NcCell {
         style: NcStyle,
         channels: NcChannels,
     ) -> NcResult<u32> {
-        let bytes = c_api::nccell_prime(plane, cell, gcluster, style, channels);
+        let bytes = c_api::nccell_prime(plane, cell, gcluster, style.into(), channels.into());
         error![bytes, "", bytes as u32]
     }
 
@@ -129,9 +129,9 @@ impl NcCell {
     ///
     /// *(No equivalent C style function)*
     pub fn channels(&mut self, plane: &mut NcPlane) -> NcChannels {
-        let (mut _styles, mut channels) = (0, 0);
-        let _egc = c_api::nccell_extract(plane, self, &mut _styles, &mut channels);
-        channels
+        let (mut styles, mut channels) = (0, 0);
+        let _egc = c_api::nccell_extract(plane, self, &mut styles, &mut channels);
+        channels.into()
     }
 
     /// Extracts the background [`NcAlpha`] (shifted to LSBs).
@@ -167,13 +167,13 @@ impl NcCell {
     ///
     /// *C style function: [nccell_bg_rgb()][c_api::nccell_bg_rgb].*
     pub fn bg_rgb(&self) -> NcRgb {
-        c_api::nccell_bg_rgb(self)
+        c_api::nccell_bg_rgb(self).into()
     }
 
-    /// Gets the background RGB [`NcComponent`]s.
+    /// Gets the background RGB components.
     ///
     /// *C style function: [nccell_bg_rgb8()][c_api::nccell_bg_rgb8].*
-    pub fn bg_rgb8(&self) -> (NcComponent, NcComponent, NcComponent) {
+    pub fn bg_rgb8(&self) -> (u8, u8, u8) {
         let (mut r, mut g, mut b) = (0, 0, 0);
         c_api::nccell_bg_rgb8(self, &mut r, &mut g, &mut b);
         (r, g, b)
@@ -212,13 +212,13 @@ impl NcCell {
     ///
     /// *C style function: [nccell_fg_rgb()][c_api::nccell_fg_rgb].*
     pub fn fg_rgb(&self) -> NcRgb {
-        c_api::nccell_fg_rgb(self)
+        c_api::nccell_fg_rgb(self).into()
     }
 
-    /// Gets the foreground RGB [`NcComponent`]s.
+    /// Gets the foreground RGB components.
     ///
     /// *C style function: [nccell_fg_rgb8()][c_api::nccell_fg_rgb8].*
-    pub fn fg_rgb8(&self) -> (NcComponent, NcComponent, NcComponent) {
+    pub fn fg_rgb8(&self) -> (u8, u8, u8) {
         let (mut r, mut g, mut b) = (0, 0, 0);
         c_api::nccell_fg_rgb8(self, &mut r, &mut g, &mut b);
         (r, g, b)
@@ -254,15 +254,15 @@ impl NcCell {
     /// Sets the background [`NcRgb`] and marks it as not using the default color.
     ///
     /// *C style function: [nccell_set_bg_rgb()][c_api::nccell_set_bg_rgb].*
-    pub fn set_bg_rgb(&mut self, rgb: NcRgb) {
-        c_api::nccell_set_bg_rgb(self, rgb);
+    pub fn set_bg_rgb<RGB: Into<NcRgb>>(&mut self, rgb: RGB) {
+        c_api::nccell_set_bg_rgb(self, rgb.into().into());
     }
 
-    /// Sets the background RGB [`NcComponent`]s, and marks it as not using
+    /// Sets the background RGB components, and marks it as not using
     /// the "default color".
     ///
     /// *C style function: [nccell_set_bg_rgb8()][c_api::nccell_set_bg_rgb8].*
-    pub fn set_bg_rgb8(&mut self, red: NcComponent, green: NcComponent, blue: NcComponent) {
+    pub fn set_bg_rgb8(&mut self, red: u8, green: u8, blue: u8) {
         c_api::nccell_set_bg_rgb8(self, red, green, blue);
     }
 
@@ -296,15 +296,15 @@ impl NcCell {
     /// Sets the foreground [`NcRgb`] and marks it as not using the default color.
     ///
     /// *C style function: [nccell_set_fg_rgb()][c_api::nccell_set_fg_rgb].*
-    pub fn set_fg_rgb(&mut self, rgb: NcRgb) {
-        c_api::nccell_set_fg_rgb(self, rgb);
+    pub fn set_fg_rgb<RGB: Into<NcRgb>>(&mut self, rgb: RGB) {
+        c_api::nccell_set_fg_rgb(self, rgb.into().into());
     }
 
-    /// Sets the foreground RGB [`NcComponent`]s, and marks it as not using
+    /// Sets the foreground RGB components, and marks it as not using
     /// the "default color".
     ///
     /// *C style function: [nccell_set_fg_rgb8()][c_api::nccell_set_fg_rgb8].*
-    pub fn set_fg_rgb8(&mut self, red: NcComponent, green: NcComponent, blue: NcComponent) {
+    pub fn set_fg_rgb8(&mut self, red: u8, green: u8, blue: u8) {
         c_api::nccell_set_fg_rgb8(self, red, green, blue);
     }
 }
@@ -332,7 +332,7 @@ impl NcCell {
         styles: &mut NcStyle,
         channels: &mut NcChannels,
     ) -> String {
-        c_api::nccell_extract(plane, self, styles, channels)
+        c_api::nccell_extract(plane, self, styles.into(), channels.into())
     }
 
     /// Returns the `EGC` of the `NcCell`.
@@ -349,28 +349,28 @@ impl NcCell {
     ///
     /// *C style function: [nccell_styles()][c_api::nccell_styles].*
     pub fn styles(&mut self) -> NcStyle {
-        c_api::nccell_styles(self)
+        c_api::nccell_styles(self).into()
     }
 
     /// Removes the specified [`NcStyle`] bits.
     ///
     /// *C style function: [nccell_off_styles()][c_api::nccell_off_styles].*
     pub fn styles_off(&mut self, stylebits: NcStyle) {
-        c_api::nccell_off_styles(self, stylebits)
+        c_api::nccell_off_styles(self, stylebits.into())
     }
 
     /// Adds the specified [`NcStyle`] bits.
     ///
     /// *C style function: [nccell_on_styles()][c_api::nccell_on_styles].*
     pub fn styles_on(&mut self, stylebits: NcStyle) {
-        c_api::nccell_on_styles(self, stylebits)
+        c_api::nccell_on_styles(self, stylebits.into())
     }
 
     /// Sets just the specified [`NcStyle`] bits.
     ///
     /// *C style function: [nccell_set_styles()][c_api::nccell_set_styles].*
     pub fn styles_set(&mut self, stylebits: NcStyle) {
-        c_api::nccell_set_styles(self, stylebits)
+        c_api::nccell_set_styles(self, stylebits.into())
     }
 }
 
@@ -453,7 +453,16 @@ impl NcCell {
         gcluster: &str,
     ) -> NcResult<()> {
         error![c_api::nccells_load_box(
-            plane, style, channels, ul, ur, ll, lr, hl, vl, gcluster
+            plane,
+            style.into(),
+            channels.into(),
+            ul,
+            ur,
+            ll,
+            lr,
+            hl,
+            vl,
+            gcluster
         )]
     }
 
@@ -472,7 +481,15 @@ impl NcCell {
         vl: &mut NcCell,
     ) -> NcResult<()> {
         error![c_api::nccells_double_box(
-            plane, style, channels, ul, ur, ll, lr, hl, vl
+            plane,
+            style.into(),
+            channels.into(),
+            ul,
+            ur,
+            ll,
+            lr,
+            hl,
+            vl
         )]
     }
 
@@ -491,7 +508,15 @@ impl NcCell {
         vl: &mut NcCell,
     ) -> NcResult<()> {
         error![c_api::nccells_rounded_box(
-            plane, style, channels, ul, ur, ll, lr, hl, vl
+            plane,
+            style.into(),
+            channels.into(),
+            ul,
+            ur,
+            ll,
+            lr,
+            hl,
+            vl
         )]
     }
 
@@ -510,7 +535,15 @@ impl NcCell {
         vl: &mut NcCell,
     ) -> NcResult<()> {
         error![c_api::nccells_ascii_box(
-            plane, style, channels, ul, ur, ll, lr, hl, vl
+            plane,
+            style.into(),
+            channels.into(),
+            ul,
+            ur,
+            ll,
+            lr,
+            hl,
+            vl
         )]
     }
     /// NcCell.[load_box()][NcCell#method.box] with the heavy line
@@ -529,7 +562,15 @@ impl NcCell {
         vl: &mut NcCell,
     ) -> NcResult<()> {
         error![c_api::nccells_heavy_box(
-            plane, style, channels, ul, ur, ll, lr, hl, vl
+            plane,
+            style.into(),
+            channels.into(),
+            ul,
+            ur,
+            ll,
+            lr,
+            hl,
+            vl
         )]
     }
 
@@ -549,7 +590,15 @@ impl NcCell {
         vl: &mut NcCell,
     ) -> NcResult<()> {
         error![c_api::nccells_light_box(
-            plane, style, channels, ul, ur, ll, lr, hl, vl
+            plane,
+            style.into(),
+            channels.into(),
+            ul,
+            ur,
+            ll,
+            lr,
+            hl,
+            vl
         )]
     }
 }
