@@ -207,7 +207,7 @@ pub(crate) mod reimplemented;
 /// multicolumn glyph. whether a cell is the left or right side of the glyph
 /// can be determined by checking whether ->gcluster is zero.
 ///
-pub type NcCell = crate::bindings::ffi::nccell;
+pub type NcCell = crate::c_api::ffi::nccell;
 
 // RETHINK:
 //
