@@ -5,9 +5,10 @@
 use libc::strcmp;
 
 use crate::{
-    c_api::{self, nccell_release},
-    cstring, rstring, NcAlpha, NcCell, NcChannel, NcChannels, NcComponent, NcIntResult,
-    NcIntResultApi, NcPaletteIndex, NcPlane, NcRgb, NcStyle, NcStyleApi,
+    c_api::{
+        self, nccell_release, NcChannel_u32, NcChannels_u64, NcResult_i32, NcRgb_u32, NcStyle_u16,
+    },
+    cstring, rstring, NcAlpha, NcCell, NcPaletteIndex, NcPlane,
 };
 
 const NCBOXLIGHT: &str = "┌┐└┘─│";
@@ -51,103 +52,83 @@ pub fn nccell_set_bg_alpha(cell: &mut NcCell, alpha: NcAlpha) {
     c_api::ncchannels_set_bg_alpha(&mut cell.channels, alpha);
 }
 
-// NcComponent ---------------------------------------------------------------------
+// u8 ---------------------------------------------------------------------
 
-/// Gets the foreground [`NcComponent`]s of an [`NcCell`],
-/// and returns the [`NcChannel`] (which can have some extra bits set).
+/// Gets the foreground components of an [`NcCell`],
+/// and returns the [`NcChannel_u32`] (which can have some extra bits set).
 ///
 /// *Method: NcCell.[fg_rgb8()][NcCell#method.fg_rgb8].*
 #[inline]
-pub fn nccell_fg_rgb8(
-    cell: &NcCell,
-    red: &mut NcComponent,
-    green: &mut NcComponent,
-    blue: &mut NcComponent,
-) -> NcChannel {
+pub fn nccell_fg_rgb8(cell: &NcCell, red: &mut u8, green: &mut u8, blue: &mut u8) -> NcChannel_u32 {
     c_api::ncchannels_fg_rgb8(cell.channels, red, green, blue)
 }
 
-/// Gets the background [`NcComponent`]s of an [`NcCell`],
-/// and returns the [`NcChannel`] (which can have some extra bits set).
+/// Gets the background components of an [`NcCell`],
+/// and returns the [`NcChannel_u32`] (which can have some extra bits set).
 ///
 /// *Method: NcCell.[bg_rgb8()][NcCell#method.bg_rgb8].*
 #[inline]
-pub fn nccell_bg_rgb8(
-    cell: &NcCell,
-    red: &mut NcComponent,
-    green: &mut NcComponent,
-    blue: &mut NcComponent,
-) -> NcChannel {
+pub fn nccell_bg_rgb8(cell: &NcCell, red: &mut u8, green: &mut u8, blue: &mut u8) -> NcChannel_u32 {
     c_api::ncchannels_bg_rgb8(cell.channels, red, green, blue)
 }
 
-/// Sets the foreground [`NcComponent`]s of the [`NcCell`],
+/// Sets the foreground components of the [`NcCell`],
 /// and marks it as not using the "default color".
 ///
 /// *Method: NcCell.[set_fg_rgb8()][NcCell#method.set_fg_rgb8].*
 #[inline]
-pub fn nccell_set_fg_rgb8(
-    cell: &mut NcCell,
-    red: NcComponent,
-    green: NcComponent,
-    blue: NcComponent,
-) {
+pub fn nccell_set_fg_rgb8(cell: &mut NcCell, red: u8, green: u8, blue: u8) {
     c_api::ncchannels_set_fg_rgb8(&mut cell.channels, red, green, blue);
 }
 
-/// Sets the background [`NcComponent`]s of the [`NcCell`],
+/// Sets the background components of the [`NcCell`],
 /// and marks it as not using the "default color".
 ///
 /// *Method: NcCell.[set_bg_rgb8()][NcCell#method.set_bg_rgb8].*
 #[inline]
-pub fn nccell_set_bg_rgb8(
-    cell: &mut NcCell,
-    red: NcComponent,
-    green: NcComponent,
-    blue: NcComponent,
-) {
+pub fn nccell_set_bg_rgb8(cell: &mut NcCell, red: u8, green: u8, blue: u8) {
     c_api::ncchannels_set_bg_rgb8(&mut cell.channels, red, green, blue);
 }
 
-// NcRgb -----------------------------------------------------------------------
+// NcRgb_u32 -------------------------------------------------------------------
 
-/// Gets the foreground [`NcRgb`] from an [`NcCell`] (shifted to LSBs).
+/// Gets the foreground [`NcRgb_u32`] from an [`NcCell`] (shifted to LSBs).
 ///
 /// *Method: NcCell.[fg_rgb()][NcCell#method.fg_rgb].*
 #[inline]
-pub fn nccell_fg_rgb(cell: &NcCell) -> NcRgb {
+pub fn nccell_fg_rgb(cell: &NcCell) -> NcRgb_u32 {
     c_api::ncchannels_fg_rgb(cell.channels)
 }
 
-/// Gets the background [`NcRgb`] from an [`NcCell`] (shifted to LSBs).
+/// Gets the background [`NcRgb_u32`] from an [`NcCell`] (shifted to LSBs).
 ///
 /// *Method: NcCell.[bg_rgb()][NcCell#method.bg_rgb].*
 #[inline]
-pub fn nccell_bg_rgb(cell: &NcCell) -> NcRgb {
+pub fn nccell_bg_rgb(cell: &NcCell) -> NcRgb_u32 {
     c_api::ncchannels_bg_rgb(cell.channels)
 }
 
-/// Sets the foreground [`NcRgb`] of an [`NcCell`],
+/// Sets the foreground [`NcRgb_u32`] of an [`NcCell`],
 /// and marks it as not using the default color.
 ///
 /// *Method: NcCell.[set_fg_rgb()][NcCell#method.set_fg_rgb].*
 #[inline]
-pub fn nccell_set_fg_rgb(cell: &mut NcCell, rgb: NcRgb) {
+pub fn nccell_set_fg_rgb(cell: &mut NcCell, rgb: NcRgb_u32) {
     c_api::ncchannels_set_fg_rgb(&mut cell.channels, rgb);
 }
 
-/// Sets the background [`NcRgb`] of an [`NcCell`],
+/// Sets the background [`NcRgb_u32`] of an [`NcCell`],
 /// and marks it as not using the default color.
 ///
 /// *Method: NcCell.[set_bg_rgb()][NcCell#method.set_bg_rgb].*
 #[inline]
-pub fn nccell_set_bg_rgb(cell: &mut NcCell, rgb: NcRgb) {
+pub fn nccell_set_bg_rgb(cell: &mut NcCell, rgb: NcRgb_u32) {
     c_api::ncchannels_set_bg_rgb(&mut cell.channels, rgb);
 }
 
 // Default ---------------------------------------------------------------------
 
-/// Indicates to use the "default color" for the foreground [`NcChannel`]
+/// Indicates to use the "default color" for the foreground [`NcChannel_u32`]
 /// of an [`NcCell`].
 ///
 /// *Method: NcCell.[set_fg_default()][NcCell#method.set_fg_default].*
@@ -156,7 +137,7 @@ pub fn nccell_set_fg_default(cell: &mut NcCell) {
     c_api::ncchannels_set_fg_default(&mut cell.channels);
 }
 
-/// Indicates to use the "default color" for the background [`NcChannel`]
+/// Indicates to use the "default color" for the background [`NcChannel_u32`]
 /// of an [`NcCell`].
 ///
 /// *Method: NcCell.[set_bg_default()][NcCell#method.set_bg_default].*
@@ -165,7 +146,7 @@ pub fn nccell_set_bg_default(cell: &mut NcCell) {
     c_api::ncchannels_set_bg_default(&mut cell.channels);
 }
 
-/// Is the foreground [`NcChannel`] of this [`NcCell`] using the
+/// Is the foreground [`NcChannel_u32`] of this [`NcCell`] using the
 /// "default foreground color"?
 ///
 /// *Method: NcCell.[fg_default_p()][NcCell#method.fg_default_p].*
@@ -174,7 +155,7 @@ pub fn nccell_fg_default_p(cell: &NcCell) -> bool {
     c_api::ncchannels_fg_default_p(cell.channels)
 }
 
-/// Is the background [`NcChannel`] of this [`NcCell`] using the
+/// Is the background [`NcChannel_u32`] of this [`NcCell`] using the
 /// "default background color"?
 ///
 /// The "default background color" must generally be used to take advantage of
@@ -188,7 +169,7 @@ pub fn nccell_bg_default_p(cell: &NcCell) -> bool {
 
 // Palette ---------------------------------------------------------------------
 
-/// Is the foreground [`NcChannel`] of this [`NcCell`] using an
+/// Is the foreground [`NcChannel_u32`] of this [`NcCell`] using an
 /// [`NcPaletteIndex`] indexed [`NcPalette`][crate::NcPalette] color?
 ///
 /// *Method: NcCell.[fg_palindex_p()][NcCell#method.fg_palindex_p].*
@@ -197,7 +178,7 @@ pub fn nccell_fg_palindex_p(cell: &NcCell) -> bool {
     c_api::ncchannels_fg_palindex_p(cell.channels)
 }
 
-/// Is the background [`NcChannel`] of this [`NcCell`] using an
+/// Is the background [`NcChannel_u32`] of this [`NcCell`] using an
 /// [`NcPaletteIndex`] indexed [`NcPalette`][crate::NcPalette] color?
 ///
 /// *Method: NcCell.[bg_palindex_p()][NcCell#method.bg_palindex_p].*
@@ -206,16 +187,16 @@ pub fn nccell_bg_palindex_p(cell: &NcCell) -> bool {
     c_api::ncchannels_bg_palindex_p(cell.channels)
 }
 
-/// Gets the [`NcPaletteIndex`] of the foreground [`NcChannel`] of the [`NcCell`].
+/// Gets the [`NcPaletteIndex`] of the foreground [`NcChannel_u32`] of the [`NcCell`].
 ///
 /// *Method: NcCell.[fg_palindex()][NcCell#method.fg_palindex].*
 #[inline]
 #[allow(clippy::unnecessary_cast)]
 pub const fn nccell_fg_palindex(cell: &NcCell) -> NcPaletteIndex {
-    ((cell.channels & 0xff00000000 as NcChannels) >> 32) as NcPaletteIndex
+    ((cell.channels & 0xff00000000 as NcChannels_u64) >> 32) as NcPaletteIndex
 }
 
-/// Gets the [`NcPaletteIndex`] of the background [`NcChannel`] of the [`NcCell`].
+/// Gets the [`NcPaletteIndex`] of the background [`NcChannel_u32`] of the [`NcCell`].
 ///
 /// *Method: NcCell.[bg_palindex()][NcCell#method.bg_palindex].*
 #[inline]
@@ -226,9 +207,9 @@ pub const fn nccell_bg_palindex(cell: &NcCell) -> NcPaletteIndex {
 
 /// Sets an [`NcCell`]'s foreground [`NcPaletteIndex`].
 ///
-/// Also sets [`NcChannels::FG_PALETTE`][NcChannels#associatedconstant.FG_PALETTE]
+/// Also sets [`NcChannels_u64::FG_PALETTE`][NcChannels_u64#associatedconstant.FG_PALETTE]
 /// and [`NcAlpha::OPAQUE`][NcAlpha#associatedconstant::OPAQUE], and clears out
-/// [`NcChannels::FG_DEFAULT_MASK`][NcChannels#associatedconstant.FG_DEFAULT_MASK].
+/// [`NcChannels_u64::FG_DEFAULT_MASK`][NcChannels_u64#associatedconstant.FG_DEFAULT_MASK].
 ///
 /// Note: Unlike the original C function, this one can't fail.
 ///
@@ -240,9 +221,9 @@ pub fn nccell_set_fg_palindex(cell: &mut NcCell, index: NcPaletteIndex) {
 
 /// Sets an [`NcCell`]'s background [`NcPaletteIndex`].
 ///
-/// Also sets [`NcChannels::BG_PALETTE`][NcChannels#associatedconstant.BG_PALETTE]
+/// Also sets [`NcChannels_u64::BG_PALETTE`][NcChannels_u64#associatedconstant.BG_PALETTE]
 /// and [`NcAlpha::OPAQUE`][NcAlpha#associatedconstant::OPAQUE], and clears out
-/// [`NcChannels::BG_DEFAULT_MASK`][NcChannels#associatedconstant.BG_DEFAULT_MASK].
+/// [`NcChannels_u64::BG_DEFAULT_MASK`][NcChannels_u64#associatedconstant.BG_DEFAULT_MASK].
 ///
 /// Note: Unlike the original C function, this one can't fail.
 ///
@@ -254,38 +235,38 @@ pub fn nccell_set_bg_palindex(cell: &mut NcCell, index: NcPaletteIndex) {
 
 // Styles ----------------------------------------------------------------------
 
-/// Extracts the [`NcStyle`] bits from an [`NcCell`].
+/// Extracts the [`NcStyle_u16`] bits from an [`NcCell`].
 ///
 /// *Method: NcCell.[cell_styles()][NcCell#method.cell_styles].*
 #[inline]
-pub const fn nccell_styles(cell: &NcCell) -> NcStyle {
+pub const fn nccell_styles(cell: &NcCell) -> NcStyle_u16 {
     cell.stylemask
 }
 
-/// Adds the specified [`NcStyle`] bits to an [`NcCell`]'s existing spec.,
+/// Adds the specified [`NcStyle_u16`] bits to an [`NcCell`]'s existing spec.,
 /// whether they're actively supported or not.
 ///
 /// *Method: NcCell.[styles_on()][NcCell#method.styles_on].*
 #[inline]
-pub fn nccell_on_styles(cell: &mut NcCell, stylebits: NcStyle) {
-    cell.stylemask |= stylebits & NcStyle::MASK as u16;
+pub fn nccell_on_styles(cell: &mut NcCell, stylebits: NcStyle_u16) {
+    cell.stylemask |= stylebits & c_api::NCSTYLE_MASK as u16;
 }
 
-/// Removes the specified [`NcStyle`] bits from an [`NcCell`]'s existing spec.
+/// Removes the specified [`NcStyle_u16`] bits from an [`NcCell`]'s existing spec.
 ///
 /// *Method: NcCell.[styles_off()][NcCell#method.styles_off].*
 #[inline]
-pub fn nccell_off_styles(cell: &mut NcCell, stylebits: NcStyle) {
-    cell.stylemask &= !(stylebits & NcStyle::MASK as u16);
+pub fn nccell_off_styles(cell: &mut NcCell, stylebits: NcStyle_u16) {
+    cell.stylemask &= !(stylebits & c_api::NCSTYLE_MASK as u16);
 }
 
-/// Sets *just* the specified [`NcStyle`] bits for an [`NcCell`],
+/// Sets *just* the specified [`NcStyle_u16`] bits for an [`NcCell`],
 /// whether they're actively supported or not.
 ///
 /// *Method: NcCell.[styles_set()][NcCell#method.styles_set].*
 #[inline]
-pub fn nccell_set_styles(cell: &mut NcCell, stylebits: NcStyle) {
-    cell.stylemask = stylebits & NcStyle::MASK as u16;
+pub fn nccell_set_styles(cell: &mut NcCell, stylebits: NcStyle_u16) {
+    cell.stylemask = stylebits & c_api::NCSTYLE_MASK as u16;
 }
 
 // Chars -----------------------------------------------------------------------
@@ -339,7 +320,7 @@ pub fn nccell_strdup(plane: &NcPlane, cell: &NcCell) -> String {
 
 // Misc. -----------------------------------------------------------------------
 
-/// Saves the [`NcStyle`] and the [`NcChannels`],
+/// Saves the [`NcStyle_u16`] and the [`NcChannels_u64`],
 /// and returns the `EGC`, of an [`NcCell`].
 ///
 /// *Method: NcCell.[extract()][NcCell#method.extract].*
@@ -347,8 +328,8 @@ pub fn nccell_strdup(plane: &NcPlane, cell: &NcCell) -> String {
 pub fn nccell_extract(
     plane: &NcPlane,
     cell: &NcCell,
-    stylemask: &mut NcStyle,
-    channels: &mut NcChannels,
+    stylemask: &mut NcStyle_u16,
+    channels: &mut NcChannels_u64,
 ) -> String {
     *stylemask = cell.stylemask;
     *channels = cell.channels;
@@ -401,9 +382,9 @@ pub fn nccell_prime(
     plane: &mut NcPlane,
     cell: &mut NcCell,
     gcluster: &str,
-    style: NcStyle,
-    channels: NcChannels,
-) -> NcIntResult {
+    style: NcStyle_u16,
+    channels: NcChannels_u64,
+) -> NcResult_i32 {
     cell.stylemask = style;
     cell.channels = channels;
     unsafe { c_api::nccell_load(plane, cell, cstring![gcluster]) }
@@ -411,8 +392,8 @@ pub fn nccell_prime(
 
 /// Loads up six cells with the `EGC`s necessary to draw a box.
 ///
-/// Returns [`NcIntResult::OK`][NcIntResult#associatedconstant.OK] on success
-/// or [`NcIntResult::ERR`][NcIntResult#associatedconstant.ERR] on error.
+/// Returns [`NCRESULT_OK`][c_api::NCRESULT_OK] on success
+/// or [`NCRESULT_ERR`][c_api::NCRESULT_ERR] on error.
 ///
 /// On error, any [`NcCell`]s this function might have loaded before the error
 /// are [nccell_release]d. There must be at least six `EGC`s in `gcluster`.
@@ -421,8 +402,8 @@ pub fn nccell_prime(
 #[inline]
 pub fn nccells_load_box(
     plane: &mut NcPlane,
-    style: NcStyle,
-    channels: NcChannels,
+    style: NcStyle_u16,
+    channels: NcChannels_u64,
     ul: &mut NcCell,
     ur: &mut NcCell,
     ll: &mut NcCell,
@@ -430,13 +411,13 @@ pub fn nccells_load_box(
     hl: &mut NcCell,
     vl: &mut NcCell,
     gcluster: &str,
-) -> NcIntResult {
+) -> NcResult_i32 {
     assert![gcluster.len() >= 6]; // DEBUG
 
     // TODO: CHECK: mutable copy for pointer arithmetics:
     let mut gclu = cstring![gcluster];
 
-    let mut ulen: NcIntResult;
+    let mut ulen: NcResult_i32;
 
     ulen = nccell_prime(plane, ul, gcluster, style, channels);
 
@@ -461,7 +442,7 @@ pub fn nccells_load_box(
                         ulen = nccell_prime(plane, vl, gcluster, style, channels);
 
                         if ulen > 0 {
-                            return NcIntResult::OK;
+                            return c_api::NCRESULT_OK;
                         }
                         unsafe {
                             nccell_release(plane, hl);
@@ -483,7 +464,7 @@ pub fn nccells_load_box(
             nccell_release(plane, ul);
         }
     }
-    NcIntResult::ERR
+    c_api::NCRESULT_ERR
 }
 
 /// [`nccells_load_box`] with ASCII characters.
@@ -492,15 +473,15 @@ pub fn nccells_load_box(
 #[inline]
 pub fn nccells_ascii_box(
     plane: &mut NcPlane,
-    style: NcStyle,
-    channels: NcChannels,
+    style: NcStyle_u16,
+    channels: NcChannels_u64,
     ul: &mut NcCell,
     ur: &mut NcCell,
     ll: &mut NcCell,
     lr: &mut NcCell,
     hl: &mut NcCell,
     vl: &mut NcCell,
-) -> NcIntResult {
+) -> NcResult_i32 {
     nccells_load_box(plane, style, channels, ul, ur, ll, lr, hl, vl, NCBOXASCII)
 }
 
@@ -510,15 +491,15 @@ pub fn nccells_ascii_box(
 #[inline]
 pub fn nccells_double_box(
     plane: &mut NcPlane,
-    style: NcStyle,
-    channels: NcChannels,
+    style: NcStyle_u16,
+    channels: NcChannels_u64,
     ul: &mut NcCell,
     ur: &mut NcCell,
     ll: &mut NcCell,
     lr: &mut NcCell,
     hl: &mut NcCell,
     vl: &mut NcCell,
-) -> NcIntResult {
+) -> NcResult_i32 {
     nccells_load_box(plane, style, channels, ul, ur, ll, lr, hl, vl, NCBOXDOUBLE)
 }
 
@@ -528,15 +509,15 @@ pub fn nccells_double_box(
 #[inline]
 pub fn nccells_heavy_box(
     plane: &mut NcPlane,
-    style: NcStyle,
-    channels: NcChannels,
+    style: NcStyle_u16,
+    channels: NcChannels_u64,
     ul: &mut NcCell,
     ur: &mut NcCell,
     ll: &mut NcCell,
     lr: &mut NcCell,
     hl: &mut NcCell,
     vl: &mut NcCell,
-) -> NcIntResult {
+) -> NcResult_i32 {
     nccells_load_box(plane, style, channels, ul, ur, ll, lr, hl, vl, NCBOXHEAVY)
 }
 
@@ -546,15 +527,15 @@ pub fn nccells_heavy_box(
 #[inline]
 pub fn nccells_light_box(
     plane: &mut NcPlane,
-    style: NcStyle,
-    channels: NcChannels,
+    style: NcStyle_u16,
+    channels: NcChannels_u64,
     ul: &mut NcCell,
     ur: &mut NcCell,
     ll: &mut NcCell,
     lr: &mut NcCell,
     hl: &mut NcCell,
     vl: &mut NcCell,
-) -> NcIntResult {
+) -> NcResult_i32 {
     nccells_load_box(plane, style, channels, ul, ur, ll, lr, hl, vl, NCBOXLIGHT)
 }
 
@@ -564,14 +545,14 @@ pub fn nccells_light_box(
 #[inline]
 pub fn nccells_rounded_box(
     plane: &mut NcPlane,
-    style: NcStyle,
-    channels: NcChannels,
+    style: NcStyle_u16,
+    channels: NcChannels_u64,
     ul: &mut NcCell,
     ur: &mut NcCell,
     ll: &mut NcCell,
     lr: &mut NcCell,
     hl: &mut NcCell,
     vl: &mut NcCell,
-) -> NcIntResult {
+) -> NcResult_i32 {
     nccells_load_box(plane, style, channels, ul, ur, ll, lr, hl, vl, NCBOXROUND)
 }
