@@ -4,8 +4,8 @@ use core::ptr::{null, null_mut};
 
 use crate::{
     c_api, cstring, error, error_ref_mut, rstring_free, NcAlign, NcBlitter, NcCapabilities,
-    NcChannels, NcComponent, NcDim, NcDirect, NcDirectFlags, NcError, NcInput, NcOffset,
-    NcPaletteIndex, NcPlane, NcResult, NcRgb, NcScale, NcStyle, NcTime,
+    NcChannels, NcDirect, NcDirectFlags, NcError, NcInput, NcPaletteIndex, NcPlane, NcResult,
+    NcRgb, NcScale, NcStyle, NcTime,
 };
 
 /// # `NcDirect` constructors and destructors
@@ -16,7 +16,7 @@ impl NcDirect {
     ///
     /// Direct mode supports a limited subset of notcurses routines,
     /// and neither supports nor requires
-    /// [notcurses_render()][c_api::notcurses_render]. This can be used to add
+    /// [`notcurses_render`][c_api::notcurses_render]. This can be used to add
     /// color and styling to text in the standard output paradigm.
     ///
     /// # Safety
@@ -26,10 +26,10 @@ impl NcDirect {
     ///
     /// *C style function: [ncdirect_init()][c_api::ncdirect_init].*
     pub unsafe fn new<'a>() -> NcResult<&'a mut NcDirect> {
-        Self::with_flags(0)
+        Self::with_flags(NcDirectFlags::None)
     }
 
-    /// New NcDirect with optional flags.
+    /// New `NcDirect` with optional flags.
     ///
     /// # Safety
     /// You must not create multiple `NcDirect` instances at the same time, on
@@ -38,11 +38,11 @@ impl NcDirect {
     ///
     /// *C style function: [ncdirect_init()][c_api::ncdirect_init].*
     pub unsafe fn with_flags<'a>(flags: NcDirectFlags) -> NcResult<&'a mut NcDirect> {
-        let res = c_api::ncdirect_init(null(), null_mut(), flags);
+        let res = c_api::ncdirect_init(null(), null_mut(), flags.into());
         error_ref_mut![res, "Initializing NcDirect"]
     }
 
-    /// Releases this NcDirect and any associated resources.
+    /// Releases this `NcDirect` and any associated resources.
     ///
     /// # Safety
     /// You must not call this method repeatedly on the same `NcDirect` instance.
@@ -75,7 +75,7 @@ impl NcDirect {
     /// *C style function: [ncdirect_raster_frame()][c_api::ncdirect_raster_frame].*
     pub fn raster_frame(&mut self, frame: &mut NcPlane, align: NcAlign) -> NcResult<()> {
         error![
-            unsafe { c_api::ncdirect_raster_frame(self, frame, align) },
+            unsafe { c_api::ncdirect_raster_frame(self, frame, align.into()) },
             "NcDirect.raster_frame()"
         ]
     }
@@ -97,15 +97,15 @@ impl NcDirect {
         filename: &str,
         blitter: NcBlitter,
         scale: NcScale,
-        max_y: NcDim,
-        max_x: NcDim,
+        max_y: u32,
+        max_x: u32,
     ) -> NcResult<&'a mut NcPlane> {
         let res = unsafe {
             c_api::ncdirect_render_frame(
                 self,
                 cstring![filename],
-                blitter,
-                scale,
+                blitter.into(),
+                scale.into(),
                 max_y as i32,
                 max_x as i32,
             )
@@ -125,8 +125,8 @@ impl NcDirect {
     /// will only occupy the column of the cursor, and those to the right.
     ///
     /// The render/raster process can be split by using
-    /// [render_frame()][#method.render_frame] and
-    /// [raster_frame()][#method.raster_frame].
+    /// [`render_frame`][#method.render_frame] and
+    /// [`raster_frame`][#method.raster_frame].
     ///
     /// *C style function: [ncdirect_render_image()][c_api::ncdirect_render_image].*
     pub fn render_image(
@@ -138,7 +138,13 @@ impl NcDirect {
     ) -> NcResult<()> {
         error![
             unsafe {
-                c_api::ncdirect_render_image(self, cstring![filename], align, blitter, scale)
+                c_api::ncdirect_render_image(
+                    self,
+                    cstring![filename],
+                    align.into(),
+                    blitter.into(),
+                    scale.into(),
+                )
             },
             &format!(
                 "NcDirect.render_image({:?}, {:?}, {:?}, {:?})",
@@ -150,7 +156,7 @@ impl NcDirect {
 
 /// ## NcDirect methods: `NcPaletteIndex`, `NcRgb`, `NcStyle` & default color
 impl NcDirect {
-    /// Sets the foreground [NcPaletteIndex].
+    /// Sets the foreground [`NcPaletteIndex`].
     ///
     /// *C style function: [ncdirect_set_fg_palindex()][c_api::ncdirect_set_fg_palindex].*
     pub fn set_fg_palindex(&mut self, index: NcPaletteIndex) -> NcResult<()> {
@@ -160,7 +166,7 @@ impl NcDirect {
         ]
     }
 
-    /// Sets the background [NcPaletteIndex].
+    /// Sets the background [`NcPaletteIndex`].
     ///
     /// *C style function: [ncdirect_set_bg_palindex()][c_api::ncdirect_set_bg_palindex].*
     pub fn set_bg_palindex(&mut self, index: NcPaletteIndex) -> NcResult<()> {
@@ -188,50 +194,46 @@ impl NcDirect {
         Ok(res)
     }
 
-    /// Sets the foreground [NcRgb].
+    /// Sets the foreground [`NcRgb`].
     ///
     /// *C style function: [ncdirect_set_fg_rgb()][c_api::ncdirect_set_fg_rgb].*
-    pub fn set_fg_rgb(&mut self, rgb: NcRgb) -> NcResult<()> {
+    pub fn set_fg_rgb<RGB>(&mut self, rgb: RGB) -> NcResult<()>
+    where
+        RGB: Into<NcRgb>,
+    {
         error![
-            unsafe { c_api::ncdirect_set_fg_rgb(self, rgb) },
-            &format!("NcDirect.set_fg_rgb({})", rgb)
+            unsafe { c_api::ncdirect_set_fg_rgb(self, rgb.into().into()) },
+            "NcDirect.set_fg_rgb()"
         ]
     }
 
-    /// Sets the background [NcRgb].
+    /// Sets the background [`NcRgb`].
     ///
     /// *C style function: [ncdirect_set_bg_rgb()][c_api::ncdirect_set_bg_rgb].*
-    pub fn set_bg_rgb(&mut self, rgb: NcRgb) -> NcResult<()> {
+    pub fn set_bg_rgb<RGB>(&mut self, rgb: RGB) -> NcResult<()>
+    where
+        RGB: Into<NcRgb>,
+    {
         error![
-            unsafe { c_api::ncdirect_set_bg_rgb(self, rgb) },
-            &format!("NcDirect.set_bg_rgb({})", rgb)
+            unsafe { c_api::ncdirect_set_bg_rgb(self, rgb.into().into()) },
+            "NcDirect.set_bg_rgb({:?})"
         ]
     }
 
-    /// Sets the foreground [NcComponent] components.
+    /// Sets the foreground individual RGB components.
     ///
     /// *C style function: [ncdirect_set_fg_rgb8()][c_api::ncdirect_set_fg_rgb8].*
-    pub fn set_fg_rgb8(
-        &mut self,
-        red: NcComponent,
-        green: NcComponent,
-        blue: NcComponent,
-    ) -> NcResult<()> {
+    pub fn set_fg_rgb8(&mut self, red: u8, green: u8, blue: u8) -> NcResult<()> {
         error![
             c_api::ncdirect_set_fg_rgb8(self, red, green, blue),
             &format!("NcDirect.set_fg_rgb8({}, {}, {})", red, green, blue)
         ]
     }
 
-    /// Sets the background [NcComponent] components.
+    /// Sets the background individual RGB components.
     ///
     /// *C style function: [ncdirect_set_bg_rgb()][c_api::ncdirect_set_bg_rgb].*
-    pub fn set_bg_rgb8(
-        &mut self,
-        red: NcComponent,
-        green: NcComponent,
-        blue: NcComponent,
-    ) -> NcResult<()> {
+    pub fn set_bg_rgb8(&mut self, red: u8, green: u8, blue: u8) -> NcResult<()> {
         error![
             c_api::ncdirect_set_bg_rgb8(self, red, green, blue),
             &format!("NcDirect.set_bg_rgb8({}, {}, {})", red, green, blue)
@@ -242,7 +244,7 @@ impl NcDirect {
     ///
     /// *C style function: [ncdirect_styles()][c_api::ncdirect_styles].*
     pub fn styles(&self) -> NcStyle {
-        unsafe { c_api::ncdirect_styles(self) as NcStyle }
+        unsafe { c_api::ncdirect_styles(self).into() }
     }
 
     /// Removes the specified styles.
@@ -280,11 +282,11 @@ impl NcDirect {
     /// The attribute is only indicated as supported if the terminal can support
     /// it together with color.
     ///
-    /// For more information, see the "ncv" capability in terminfo(5).
+    /// For more information, see the "ncv" capability in *terminfo(5)*.
     ///
     /// *C style function: [ncdirect_supported_styles()][c_api::ncdirect_supported_styles].*
     pub fn supported_styles(&self) -> NcStyle {
-        unsafe { c_api::ncdirect_supported_styles(self) as NcStyle }
+        unsafe { c_api::ncdirect_supported_styles(self).into() }
     }
 
     /// Indicates to use the "default color" for the foreground.
@@ -449,7 +451,7 @@ impl NcDirect {
     /// Moves the cursor down any number of rows.
     ///
     /// *C style function: [ncdirect_cursor_down()][c_api::ncdirect_cursor_down].*
-    pub fn cursor_down(&mut self, rows: NcOffset) -> NcResult<()> {
+    pub fn cursor_down(&mut self, rows: i32) -> NcResult<()> {
         error![
             unsafe { c_api::ncdirect_cursor_down(self, rows as i32) },
             &format!("NcDirect.cursor_down({})", rows)
@@ -459,7 +461,7 @@ impl NcDirect {
     /// Moves the cursor left any number of columns.
     ///
     /// *C style function: [ncdirect_cursor_left()][c_api::ncdirect_cursor_left].*
-    pub fn cursor_left(&mut self, cols: NcOffset) -> NcResult<()> {
+    pub fn cursor_left(&mut self, cols: i32) -> NcResult<()> {
         error![
             unsafe { c_api::ncdirect_cursor_left(self, cols as i32) },
             &format!("NcDirect.cursor_left({})", cols)
@@ -469,7 +471,7 @@ impl NcDirect {
     /// Moves the cursor right any number of columns.
     ///
     /// *C style function: [ncdirect_cursor_right()][c_api::ncdirect_cursor_right].*
-    pub fn cursor_right(&mut self, cols: NcOffset) -> NcResult<()> {
+    pub fn cursor_right(&mut self, cols: i32) -> NcResult<()> {
         error![
             unsafe { c_api::ncdirect_cursor_right(self, cols as i32) },
             &format!("NcDirect.cursor_right({})", cols)
@@ -479,7 +481,7 @@ impl NcDirect {
     /// Moves the cursor up any number of rows.
     ///
     /// *C style function: [ncdirect_cursor_up()][c_api::ncdirect_cursor_up].*
-    pub fn cursor_up(&mut self, rows: NcOffset) -> NcResult<()> {
+    pub fn cursor_up(&mut self, rows: i32) -> NcResult<()> {
         error![
             unsafe { c_api::ncdirect_cursor_up(self, rows as i32) },
             &format!("NcDirect.cursor_up({})", rows)
@@ -489,21 +491,21 @@ impl NcDirect {
     /// Sets the cursor to the specified row `y`, column `x`.
     ///
     /// *C style function: [ncdirect_cursor_move_yx()][c_api::ncdirect_cursor_move_yx].*
-    pub fn cursor_set_yx(&mut self, y: NcDim, x: NcDim) -> NcResult<()> {
+    pub fn cursor_set_yx(&mut self, y: u32, x: u32) -> NcResult<()> {
         error![unsafe { c_api::ncdirect_cursor_move_yx(self, y as i32, x as i32) }]
     }
 
     /// Sets the cursor to the specified row `y`.
     ///
     /// *(No equivalent C style function)*
-    pub fn cursor_set_y(&mut self, y: NcDim) -> NcResult<()> {
+    pub fn cursor_set_y(&mut self, y: u32) -> NcResult<()> {
         error![unsafe { c_api::ncdirect_cursor_move_yx(self, y as i32, -1) }]
     }
 
     /// Sets the cursor to the specified column `x`.
     ///
     /// *(No equivalent C style function)*
-    pub fn cursor_set_x(&mut self, x: NcDim) -> NcResult<()> {
+    pub fn cursor_set_x(&mut self, x: u32) -> NcResult<()> {
         error![unsafe { c_api::ncdirect_cursor_move_yx(self, -1, x as i32) }]
     }
 
@@ -514,12 +516,12 @@ impl NcDirect {
     /// the results might be detrimental.
     ///
     /// *C style function: [ncdirect_cursor_yx()][c_api::ncdirect_cursor_yx].*
-    pub fn cursor_yx(&mut self) -> NcResult<(NcDim, NcDim)> {
+    pub fn cursor_yx(&mut self) -> NcResult<(u32, u32)> {
         let (mut y, mut x) = (0, 0);
         error![
             unsafe { c_api::ncdirect_cursor_yx(self, &mut y, &mut x) },
             "",
-            (y as NcDim, x as NcDim)
+            (y as u32, x as u32)
         ]
     }
 
@@ -544,23 +546,23 @@ impl NcDirect {
     /// Gets the current number of rows.
     ///
     /// *C style function: [ncdirect_dim_y()][c_api::ncdirect_dim_y].*
-    pub fn dim_y(&mut self) -> NcDim {
-        unsafe { c_api::ncdirect_dim_y(self) as NcDim }
+    pub fn dim_y(&mut self) -> u32 {
+        unsafe { c_api::ncdirect_dim_y(self) as u32 }
     }
 
     /// Gets the current number of columns.
     ///
     /// *C style function: [ncdirect_dim_x()][c_api::ncdirect_dim_x].*
-    pub fn dim_x(&mut self) -> NcDim {
-        unsafe { c_api::ncdirect_dim_x(self) as NcDim }
+    pub fn dim_x(&mut self) -> u32 {
+        unsafe { c_api::ncdirect_dim_x(self) as u32 }
     }
 
     /// Gets the current number of rows and columns.
     ///
     /// *C style function: [ncdirect_dim_y()][c_api::ncdirect_dim_y].*
-    pub fn dim_yx(&mut self) -> (NcDim, NcDim) {
-        let y = unsafe { c_api::ncdirect_dim_y(self) as NcDim };
-        let x = unsafe { c_api::ncdirect_dim_x(self) as NcDim };
+    pub fn dim_yx(&mut self) -> (u32, u32) {
+        let y = unsafe { c_api::ncdirect_dim_y(self) as u32 };
+        let x = unsafe { c_api::ncdirect_dim_x(self) as u32 };
         (y, x)
     }
 
@@ -631,8 +633,8 @@ impl NcDirect {
 
     /// Get a file descriptor suitable for input event poll()ing.
     ///
-    /// When this descriptor becomes available, you can call
-    /// [get_nblock()][NcDirect#method.get_nblock], and input ought be ready.
+    /// When this descriptor becomes available, you can call `NcDirect.`
+    /// [`get_nblock`][NcDirect#method.get_nblock], and input ought be ready.
     ///
     /// This file descriptor is not necessarily the file descriptor associated
     /// with stdin (but it might be!).
@@ -654,7 +656,7 @@ impl NcDirect {
     /// *C style function: [ncdirect_putstr()][c_api::ncdirect_putstr].*
     pub fn putstr(&mut self, channels: NcChannels, string: &str) -> NcResult<()> {
         error![
-            unsafe { c_api::ncdirect_putstr(self, channels, cstring![string]) },
+            unsafe { c_api::ncdirect_putstr(self, channels.into(), cstring![string]) },
             &format!("NcDirect.putstr({:0X}, {:?})", channels, string)
         ]
     }
@@ -664,8 +666,9 @@ impl NcDirect {
     /// Initializes Readline the first time it's called.
     ///
     /// For input to be echoed to the terminal, it is necessary that the flag
-    /// [`NcDirectFlags::INHIBIT_CBREAK`][NcDirectFlags#associatedconstant.INHIBIT_CBREAK]
-    /// be provided to the constructor.
+    /// [`NcDirectFlags::INHIBIT_CBREAK`][0] be provided to the constructor.
+    ///
+    /// [0]: NcDirectFlags#associatedconstant.INHIBIT_CBREAK
     ///
     /// *C style function: [ncdirect_readline()][c_api::ncdirect_readline].*
     //
@@ -685,7 +688,7 @@ impl NcDirect {
     /// Draws a box with its upper-left corner at the current cursor position,
     /// having dimensions `ylen` * `xlen`.
     ///
-    /// See NcPlane.[box()][NcPlane#method.box] for more information.
+    /// See `NcPlane.`[`box`][NcPlane#method.box] for more information.
     ///
     /// The minimum box size is 2x2, and it cannot be drawn off-screen.
     ///
@@ -700,14 +703,14 @@ impl NcDirect {
         ll: NcChannels,
         lr: NcChannels,
         wchars: &[char; 6],
-        len_y: NcDim,
-        len_x: NcDim,
+        len_y: u32,
+        len_x: u32,
         ctlword: u32,
     ) -> NcResult<()> {
         error![
             unsafe {
                 let wchars = core::mem::transmute(wchars);
-                c_api::ncdirect_box(self, ul, ur, ll, lr, wchars, len_y, len_x, ctlword)
+                c_api::ncdirect_box(self, ul.0, ur.0, ll.0, lr.0, wchars, len_y, len_x, ctlword)
             },
             &format!(
                 "NcDirect.box({:0X}, {:0X}, {:0X}, {:0X}, {:?}, {}, {}, {})",
@@ -716,7 +719,7 @@ impl NcDirect {
         ]
     }
 
-    /// NcDirect.[box()][NcDirect#method.box] with the double box-drawing characters.
+    /// `NcDirect.`[`box`][NcDirect#method.box] with the double box-drawing characters.
     ///
     /// *C style function: [ncdirect_double_box()][c_api::ncdirect_double_box].*
     pub fn double_box(
@@ -725,14 +728,16 @@ impl NcDirect {
         ur: NcChannels,
         ll: NcChannels,
         lr: NcChannels,
-        len_y: NcDim,
-        len_x: NcDim,
+        len_y: u32,
+        len_x: u32,
         ctlword: u32,
     ) -> NcResult<()> {
-        error![unsafe { c_api::ncdirect_double_box(self, ul, ur, ll, lr, len_y, len_x, ctlword) }]
+        error![unsafe {
+            c_api::ncdirect_double_box(self, ul.0, ur.0, ll.0, lr.0, len_y, len_x, ctlword)
+        }]
     }
 
-    /// NcDirect.[box()][NcDirect#method.box] with the rounded box-drawing characters.
+    /// `NcDirect.`[`box`][NcDirect#method.box] with the rounded box-drawing characters.
     ///
     /// *C style function: [ncdirect_rounded_box()][c_api::ncdirect_rounded_box].*
     pub fn rounded_box(
@@ -741,11 +746,13 @@ impl NcDirect {
         ur: NcChannels,
         ll: NcChannels,
         lr: NcChannels,
-        len_y: NcDim,
-        len_x: NcDim,
+        len_y: u32,
+        len_x: u32,
         ctlword: u32,
     ) -> NcResult<()> {
-        error![unsafe { c_api::ncdirect_rounded_box(self, ul, ur, ll, lr, len_y, len_x, ctlword) }]
+        error![unsafe {
+            c_api::ncdirect_rounded_box(self, ul.0, ur.0, ll.0, lr.0, len_y, len_x, ctlword)
+        }]
     }
 
     /// Draws horizontal lines using the specified [NcChannels]s, interpolating
@@ -763,11 +770,11 @@ impl NcDirect {
     pub fn hline_interp(
         &mut self,
         egc: &str,
-        len: NcDim,
+        len: u32,
         h1: NcChannels,
         h2: NcChannels,
     ) -> NcResult<()> {
-        error![c_api::ncdirect_hline_interp(self, egc, len, h1, h2)]
+        error![c_api::ncdirect_hline_interp(self, egc, len, h1.0, h2.0)]
     }
 
     /// Draws horizontal lines using the specified [NcChannels]s, interpolating
@@ -785,10 +792,10 @@ impl NcDirect {
     pub fn vline_interp(
         &mut self,
         egc: &str,
-        len: NcDim,
+        len: u32,
         h1: NcChannels,
         h2: NcChannels,
     ) -> NcResult<()> {
-        error![c_api::ncdirect_vline_interp(self, egc, len, h1, h2)]
+        error![c_api::ncdirect_vline_interp(self, egc, len, h1.0, h2.0)]
     }
 }
