@@ -3,8 +3,8 @@
 use core::ptr::{null, null_mut};
 
 use crate::{
-    c_api, cstring, NcCapabilities, NcChannels, NcComponent, NcDim, NcDirect, NcInput, NcIntResult,
-    NcRgb, NcTime,
+    c_api::{self, NcChannels_u64, NcResult_i32, NcRgb_u32},
+    cstring, NcCapabilities, NcDirect, NcInput, NcTime,
 };
 
 /// Can we directly specify RGB values per cell, or only use palettes?
@@ -64,7 +64,7 @@ pub fn ncdirect_canbraille(ncd: &NcDirect) -> bool {
 /// Returns the detected [`NcCapabilities`].
 #[inline]
 pub fn ncdirect_capabilities(ncd: &NcDirect) -> NcCapabilities {
-    unsafe { *crate::bindings::ffi::ncdirect_capabilities(ncd) }
+    unsafe { *crate::c_api::ffi::ncdirect_capabilities(ncd) }
 }
 
 /// Reads input blocking until an event is processed or a signal is received.
@@ -75,14 +75,14 @@ pub fn ncdirect_capabilities(ncd: &NcDirect) -> NcCapabilities {
 ///
 /// *Method: NcDirect.[get_blocking()][NcDirect#method.get_blocking].*
 #[inline]
-pub fn ncdirect_get_blocking(ncd: &mut NcDirect, input: Option<&mut NcInput>) -> NcIntResult {
+pub fn ncdirect_get_blocking(ncd: &mut NcDirect, input: Option<&mut NcInput>) -> NcResult_i32 {
     let input_ptr;
     if let Some(i) = input {
         input_ptr = i as *mut _;
     } else {
         input_ptr = null_mut();
     }
-    unsafe { c_api::ncdirect_get(ncd, null(), input_ptr) as NcIntResult }
+    unsafe { c_api::ncdirect_get(ncd, null(), input_ptr) as NcResult_i32 }
 }
 
 /// Reads input without blocking.
@@ -95,7 +95,7 @@ pub fn ncdirect_get_blocking(ncd: &mut NcDirect, input: Option<&mut NcInput>) ->
 ///
 /// *Method: NcDirect.[get_nblock()][NcDirect#method.get_nblock].*
 #[inline]
-pub fn ncdirect_get_nblock(ncd: &mut NcDirect, input: Option<&mut NcInput>) -> NcIntResult {
+pub fn ncdirect_get_nblock(ncd: &mut NcDirect, input: Option<&mut NcInput>) -> NcResult_i32 {
     let input_ptr;
     if let Some(i) = input {
         input_ptr = i as *mut _;
@@ -104,39 +104,29 @@ pub fn ncdirect_get_nblock(ncd: &mut NcDirect, input: Option<&mut NcInput>) -> N
     }
     unsafe {
         let ts = NcTime::new(0, 0);
-        c_api::ncdirect_get(ncd, &ts, input_ptr) as NcIntResult
+        c_api::ncdirect_get(ncd, &ts, input_ptr) as NcResult_i32
     }
 }
 
-/// Sets the foreground [`NcComponent`] components.
+/// Sets the foreground component components.
 ///
 /// *Method: NcDirect.[set_fg_rgb8()][NcDirect#method.set_fg_rgb8].*
 #[inline]
-pub fn ncdirect_set_fg_rgb8(
-    ncd: &mut NcDirect,
-    red: NcComponent,
-    green: NcComponent,
-    blue: NcComponent,
-) -> NcIntResult {
-    let rgb = (red as NcRgb) << 16 | (green as NcRgb) << 8 | blue as NcRgb;
+pub fn ncdirect_set_fg_rgb8(ncd: &mut NcDirect, red: u8, green: u8, blue: u8) -> NcResult_i32 {
+    let rgb = (red as NcRgb_u32) << 16 | (green as NcRgb_u32) << 8 | blue as NcRgb_u32;
     unsafe { c_api::ncdirect_set_fg_rgb(ncd, rgb) }
 }
 
-/// Sets the background [`NcComponent`] components.
+/// Sets the background component components.
 ///
 /// *Method: NcDirect.[set_bg_rgb8()][NcDirect#method.set_bg_rgb8].*
 #[inline]
-pub fn ncdirect_set_bg_rgb8(
-    ncd: &mut NcDirect,
-    red: NcComponent,
-    green: NcComponent,
-    blue: NcComponent,
-) -> NcIntResult {
-    let rgb = (red as NcRgb) << 16 | (green as NcRgb) << 8 | blue as NcRgb;
+pub fn ncdirect_set_bg_rgb8(ncd: &mut NcDirect, red: u8, green: u8, blue: u8) -> NcResult_i32 {
+    let rgb = (red as NcRgb_u32) << 16 | (green as NcRgb_u32) << 8 | blue as NcRgb_u32;
     unsafe { c_api::ncdirect_set_bg_rgb(ncd, rgb) }
 }
 
-/// Draws horizontal lines using the specified [`NcChannels`]s, interpolating
+/// Draws horizontal lines using the specified [`NcChannels_u64`]s, interpolating
 /// between them as we go.
 ///
 /// The string at `egc` may not use more than one column.
@@ -152,19 +142,19 @@ pub fn ncdirect_set_bg_rgb8(
 pub fn ncdirect_hline_interp(
     ncd: &mut NcDirect,
     egc: &str,
-    len: NcDim,
-    h1: NcChannels,
-    h2: NcChannels,
-) -> NcIntResult {
+    len: u32,
+    h1: NcChannels_u64,
+    h2: NcChannels_u64,
+) -> NcResult_i32 {
     #[cfg(any(target_arch = "armv7l", target_arch = "i686"))]
     let egc_ptr = cstring![egc] as *const i8;
     #[cfg(not(any(target_arch = "armv7l", target_arch = "i686")))]
     let egc_ptr = cstring![egc];
 
-    unsafe { crate::bindings::ffi::ncdirect_hline_interp(ncd, egc_ptr, len, h1, h2) }
+    unsafe { crate::c_api::ffi::ncdirect_hline_interp(ncd, egc_ptr, len, h1, h2) }
 }
 
-/// Draws horizontal lines using the specified [`NcChannels`]s, interpolating
+/// Draws horizontal lines using the specified [`NcChannels_u64`]s, interpolating
 /// between them as we go.
 ///
 /// The string at `egc` may not use more than one column.
@@ -179,14 +169,14 @@ pub fn ncdirect_hline_interp(
 pub fn ncdirect_vline_interp(
     ncd: &mut NcDirect,
     egc: &str,
-    len: NcDim,
-    h1: NcChannels,
-    h2: NcChannels,
-) -> NcIntResult {
+    len: u32,
+    h1: NcChannels_u64,
+    h2: NcChannels_u64,
+) -> NcResult_i32 {
     #[cfg(any(target_arch = "armv7l", target_arch = "i686"))]
     let egc_ptr = cstring![egc] as *const i8;
     #[cfg(not(any(target_arch = "armv7l", target_arch = "i686")))]
     let egc_ptr = cstring![egc];
 
-    unsafe { crate::bindings::ffi::ncdirect_vline_interp(ncd, egc_ptr, len, h1, h2) }
+    unsafe { crate::c_api::ffi::ncdirect_vline_interp(ncd, egc_ptr, len, h1, h2) }
 }
