@@ -11,22 +11,25 @@
 
 use std::ffi::c_void;
 
-use crate::{c_api, Nc, NcIntResult, NcPlane, NcTime};
+use crate::{
+    c_api::{self, NcResult_i32},
+    Nc, NcPlane, NcTime,
+};
 
-/// Called for each fade iteration on the NcPlane.
+/// Called for each fade iteration on a fading [`NcPlane`].
 ///
 /// If anything but 0 is returned, the fading operation ceases immediately,
 /// and that value is propagated out.
 ///
 /// The recommended absolute display time target is passed in 'tspec'.
 pub type NcFadeCb =
-    Option<unsafe extern "C" fn(*mut Nc, *mut NcPlane, *const NcTime, *mut c_void) -> NcIntResult>;
+    Option<unsafe extern "C" fn(*mut Nc, *mut NcPlane, *const NcTime, *mut c_void) -> NcResult_i32>;
 
 /// Context for a palette fade operation
-pub type NcFadeCtx = crate::bindings::ffi::ncfadectx;
+pub type NcFadeCtx = crate::c_api::ffi::ncfadectx;
 
 impl NcFadeCtx {
-    /// NcFadeCtx constructor.
+    /// `NcFadeCtx` constructor.
     ///
     /// Rather than the simple ncplane_fade{in/out}(),
     /// ncfadectx_setup() can be paired with a loop over
