@@ -20,20 +20,22 @@
 //!
 //! ### Notes on the Rust API
 //!
-//! The `Drop` trait is not implemented for any wrapping type in this library.
+//! The `Drop` trait is not implemented for any wrapping type in this library
+//! over structures created by the underlying C library.
 //!
 //! This means you still have to manually call the `stop()` method for `Nc`
 //! and `NcDirect` objects, and the `destroy()` method for the rest of types that
-//! allocate, (like `NcPlane`, `NcMenu`…) at the end of their scope, since the
+//! allocate, (like `NcPlane`, `NcMenu`…) at the end of their scope.
 //!
 //! But they do implement methods and use `NcResult` as the return type,
 //! for handling errors in the way we are used to in Rust.
 //!
 //! For the types that don't allocate, most are based on primitives like `i32`,
 //! `u32`, `u64`… without a name in the C library. In Rust they are type aliased
-//! (e.g.: `NcChannel`, `NcChannelPair`, `NcRgb`, `NcColor`…), to
-//! leverage type checking, and they implement methods through traits
-//! (e.g. `NcChannelApi` must be in scope to use the `NcChannel` methods.
+//! for the C API (e.g.: `NcChannel_u32`, `NcLogLevel_i32`, `NcStyle_u16`…), to
+//! leverage type checking. And for the Rust API they are wrapped as unit structs
+//! or enums, with associated methods and constants (e.g. `NcChannel`,
+//! `NcLogLevel`, `NcStyle`…).
 //!
 //! Several methods are declared unsafe when they have addittional contracts to
 //! manually upheld in order to avoid *UB*.
@@ -52,7 +54,7 @@
 //!
 //! It requires more use of unsafe, since it has less safer abstractions.
 //!
-//! Error handling is done this way by checking the returned `NcIntResult`,
+//! Error handling is done this way by checking the returned `NcResult_i32`,
 //! or in case of receiving a pointer, by comparing it to `null_mut()`.
 //!
 //! ### Example
@@ -79,7 +81,6 @@ mod r#box;
 mod capabilities;
 mod cell;
 mod channel;
-mod dimension;
 mod direct;
 mod error;
 mod fade;
@@ -95,6 +96,7 @@ mod palette;
 mod pixel;
 mod plane;
 mod resizecb;
+mod rgb;
 mod scale;
 mod stats;
 mod string;
@@ -106,9 +108,6 @@ pub mod widgets;
 
 // wrapper types and traits
 //
-// `*Api` traits allows using methods and associated constants over type aliased
-// primitives, like in the case of `NcAlign`, for example.
-//
 // Note that the names of the implemented traits can't coincide for type aliases
 // with the same underlying primitive, like in the case of `NcAlign` & `NcScale`
 // in which case are both aliases over `u32`.
@@ -117,34 +116,31 @@ pub use alpha::NcAlpha;
 pub use blitter::NcBlitter;
 pub use capabilities::NcCapabilities;
 pub use cell::NcCell;
-pub use channel::{NcChannel, NcChannelApi, NcChannels, NcChannelsApi, NcComponent, NcRgb};
-pub use dimension::{NcDim, NcOffset};
-pub use direct::{NcDirect, NcDirectFlags, NcDirectFlagsApi};
-pub use error::{NcError, NcIntResult, NcIntResultApi, NcResult};
+pub use channel::{NcChannel, NcChannels};
+pub use direct::{NcDirect, NcDirectFlags};
+pub use error::{NcError, NcResult};
 pub use fade::{NcFadeCb, NcFadeCtx};
 pub use fd::{NcFdPlane, NcFdPlaneOptions, NcSubproc, NcSubprocOptions};
 pub use file::NcFile;
-pub use input::{NcEvType, NcEvTypeApi, NcInput, NcMiceEvents, NcMiceEventsApi, NcReceived};
-pub use key::NcKey;
-pub use log_level::{NcLogLevel, NcLogLevelApi};
-pub use macros::*;
-pub use notcurses::{Nc, NcOptions};
+pub use input::{NcInput, NcInputType, NcMiceEvents, NcReceived};
+pub use key::{NcKey, NcKeyMod};
+pub use log_level::NcLogLevel;
+pub use notcurses::{Nc, NcFlags, NcOptions};
 pub use palette::{NcPalette, NcPaletteIndex};
-pub use pixel::{NcPixel, NcPixelApi, NcPixelGeometry, NcPixelImpl, NcPixelImplApi};
+pub use pixel::{NcPixel, NcPixelGeometry, NcPixelImpl};
 pub use plane::{NcPlane, NcPlaneOptions, NcPlaneOptionsBuilder};
-pub use r#box::{NcBoxMask, NcBoxMaskApi};
-pub use resizecb::{NcResizeCb, NcResizeCbApi, NcResizeCbUnsafe};
+pub use r#box::NcBoxMask;
+pub use resizecb::NcResizeCb;
+pub use rgb::{NcRgb, NcRgba};
 pub use scale::NcScale;
 pub use stats::NcStats;
 pub use string::NcString;
-pub use style::{NcStyle, NcStyleApi};
+pub use style::NcStyle;
 pub use time::NcTime;
-pub use visual::{
-    NcRgba, NcVGeom, NcVisual, NcVisualGeometry, NcVisualOptions, NcVisualOptionsBuilder,
-};
+pub use visual::{NcVisual, NcVisualGeometry, NcVisualOptions, NcVisualOptionsBuilder};
 
 pub mod c_api {
-    //! The C API including global constants, functions and structs.
+    //! The `C API`, including structs, constants, functions and type aliases.
     //!
     //! Includes also both automatically imported functions by bindgen, and
     //! manually wrapped and reimplemented global functions.
@@ -154,10 +150,6 @@ pub mod c_api {
 
     pub mod ffi {
         //! Rust FFI bindings, automatically generated with bindgen.
-        //!
-        //! Almost all of the notcurses API functions are reexported to the public
-        //! API, while structs, enums and constants are type aliased or wrapped up.
-        //!
         pub use crate::bindings::ffi::*;
     }
 
@@ -177,33 +169,34 @@ pub mod c_api {
     pub use crate::palette::reimplemented::*;
     pub use crate::pixel::reimplemented::*;
     pub use crate::plane::reimplemented::*;
-    pub use crate::resizecb::reimplemented::*;
 
     // public re-export of c_api constants & types:
     pub use crate::align::c_api::*;
     pub use crate::alpha::c_api::*;
     pub use crate::blitter::c_api::*;
-    pub use crate::channel::constants::*;
-    pub use crate::direct::constants::*;
-    pub use crate::error::constants::*;
-    pub use crate::input::constants::*;
-    pub use crate::key::constants::*;
-    pub use crate::log_level::constants::*;
-    pub use crate::metric::constants::*;
-    pub use crate::notcurses::constants::*;
-    pub use crate::palette::constants::*;
-    pub use crate::pixel::constants::*;
-    pub use crate::plane::options::constants::*;
-    pub use crate::r#box::constants::*;
+    pub use crate::channel::c_api::*;
+    pub use crate::direct::c_api::*;
+    pub use crate::error::c_api::*;
+    pub use crate::input::c_api::*;
+    pub use crate::key::c_api::*;
+    pub use crate::log_level::c_api::*;
+    pub use crate::metric::c_api::*;
+    pub use crate::notcurses::c_api::*;
+    pub use crate::palette::c_api::*;
+    pub use crate::pixel::c_api::*;
+    pub use crate::plane::options::c_api::*;
+    pub use crate::r#box::c_api::*;
+    pub use crate::resizecb::c_api::*;
+    pub use crate::rgb::c_api::*;
     pub use crate::scale::c_api::*;
-    pub use crate::style::constants::*;
-    pub use crate::visual::options::constants::*;
-    pub use crate::widgets::menu::constants::*;
-    pub use crate::widgets::plot::constants::*;
-    pub use crate::widgets::progbar::constants::*;
-    pub use crate::widgets::reader::constants::*;
-    pub use crate::widgets::reel::constants::*;
-    pub use crate::widgets::tabbed::constants::*;
+    pub use crate::style::c_api::*;
+    pub use crate::visual::c_api::*;
+    pub use crate::widgets::menu::c_api::*;
+    pub use crate::widgets::plot::c_api::*;
+    pub use crate::widgets::progbar::c_api::*;
+    pub use crate::widgets::reader::c_api::*;
+    pub use crate::widgets::reel::c_api::*;
+    pub use crate::widgets::tabbed::c_api::*;
 
     // private re-export of helper functions for testing:
     mod helpers {
@@ -226,7 +219,7 @@ pub mod c_api {
 //
 // [0]: https://doc.rust-lang.org/reference/items/modules.html#the-path-attribute
 #[path = "../examples"]
-#[cfg(any(doc, test))]
+#[cfg(any(doc))]
 pub mod examples {
     #![allow(dead_code)]
 
