@@ -5,26 +5,26 @@ use core::ptr::{null, null_mut};
 use crate::{
     c_api::{self, notcurses_init},
     cstring, error, error_ref_mut, rstring, rstring_free, Nc, NcAlign, NcBlitter, NcCapabilities,
-    NcChannels, NcDim, NcError, NcFile, NcInput, NcLogLevel, NcMiceEvents, NcMiceEventsApi,
-    NcOptions, NcPixelImpl, NcPlane, NcReceived, NcResult, NcRgb, NcScale, NcStats, NcStyle,
-    NcStyleApi, NcTime, NcVGeom, NcVisual, NcVisualGeometry, NcVisualOptions,
+    NcChannels, NcError, NcFile, NcFlags, NcInput, NcLogLevel, NcMiceEvents, NcOptions,
+    NcPixelImpl, NcPlane, NcReceived, NcResult, NcRgb, NcScale, NcStats, NcStyle, NcTime, NcVisual,
+    NcVisualGeometry, NcVisualOptions,
 };
 
 /// # `NcOptions` Constructors
 impl NcOptions {
     /// New `NcOptions`.
-    pub const fn new() -> Self {
-        Self::with_all_options(0, 0, 0, 0, 0, 0)
+    pub fn new() -> Self {
+        Self::with_all_options(NcLogLevel::Silent, 0, 0, 0, 0, NcFlags::None)
     }
 
     /// New `NcOptions`, with margins.
-    pub const fn with_margins(top: NcDim, right: NcDim, bottom: NcDim, left: NcDim) -> Self {
-        Self::with_all_options(0, top, right, bottom, left, 0)
+    pub fn with_margins(top: u32, right: u32, bottom: u32, left: u32) -> Self {
+        Self::with_all_options(NcLogLevel::Silent, top, right, bottom, left, NcFlags::None)
     }
 
     /// New `NcOptions`, with flags.
-    pub const fn with_flags(flags: u64) -> Self {
-        Self::with_all_options(0, 0, 0, 0, 0, flags)
+    pub fn with_flags(flags: NcFlags) -> Self {
+        Self::with_all_options(NcLogLevel::Silent, 0, 0, 0, 0, flags)
     }
 
     /// New `NcOptions`, with all the options.
@@ -50,15 +50,23 @@ impl NcOptions {
     ///   General flags; This is expressed as a bitfield so that future options
     ///   can be added without reshaping the struct.
     ///   Undefined bits must be set to 0.
-    pub const fn with_all_options(
+    pub fn with_all_options(
         loglevel: NcLogLevel,
-        margin_t: NcDim,
-        margin_r: NcDim,
-        margin_b: NcDim,
-        margin_l: NcDim,
-        flags: u64,
+        margin_t: u32,
+        margin_r: u32,
+        margin_b: u32,
+        margin_l: u32,
+        flags: NcFlags,
     ) -> Self {
-        Self { termtype: null(), loglevel, margin_t, margin_r, margin_b, margin_l, flags }
+        Self {
+            termtype: null(),
+            loglevel: loglevel.into(),
+            margin_t,
+            margin_r,
+            margin_b,
+            margin_l,
+            flags: flags.into(),
+        }
     }
 }
 
@@ -73,28 +81,23 @@ impl Nc {
     /// the same thread. You must [`stop`][Nc#method.stop] the current one
     /// before creating a new one.
     pub unsafe fn new<'a>() -> NcResult<&'a mut Nc> {
-        Self::with_flags(NcOptions::SUPPRESS_BANNERS)
+        Self::with_flags(NcFlags::SuppressBanners)
     }
 
     /// New notcurses context in CLI mode.
     ///
     /// It has the following flags:
-    /// - [`NcOptions::SUPPRESS_BANNERS`][NcOptions#associatedconstant.SUPPRESS_BANNERS]
-    /// - [`NcOptions::NO_ALTERNATE_SCREEN`][NcOptions#associatedconstant.NO_ALTERNATE_SCREEN]
-    /// - [`NcOptions::NO_CLEAR_BITMAPS`][NcOptions#associatedconstant.NO_CLEAR_BITMAPS]
-    /// - [`NcOptions::PRESERVE_CURSOR`][NcOptions#associatedconstant.PRESERVE_CURSOR]
+    /// - [`NcFlags::SuppressBanners`][NcFlags#associatedconstant.SuppressBanners]
+    /// - [`NcFlags::NoAlternateScreen`][NcFlags#associatedconstant.NoAlternateScreen]
+    /// - [`NcFlags::NoClearBitmaps`][NcFlags#associatedconstant.NoClearBitmaps]
+    /// - [`NcFlags::PreserveCursor`][NcFlags#associatedconstant.PreserveCursor]
     ///
     /// # Safety
     /// You must not create multiple `Nc` instances at the same time, on
     /// the same thread. You must [`stop`][Nc#method.stop] the current one
     /// before creating a new one.
     pub unsafe fn new_cli<'a>() -> NcResult<&'a mut Nc> {
-        Self::with_flags(
-            NcOptions::SUPPRESS_BANNERS
-                | NcOptions::NO_ALTERNATE_SCREEN
-                | NcOptions::NO_CLEAR_BITMAPS
-                | NcOptions::PRESERVE_CURSOR,
-        )
+        Self::with_flags(NcFlags::CliMode)
     }
 
     /// New notcurses context, with banners.
@@ -106,7 +109,7 @@ impl Nc {
     /// the same thread. You must [`stop`][Nc#method.stop] the current one
     /// before creating a new one.
     pub unsafe fn with_banners<'a>() -> NcResult<&'a mut Nc> {
-        Self::with_flags(0)
+        Self::with_flags(NcFlags::None)
     }
 
     /// New notcurses context, without an alternate screen (nor banners).
@@ -114,16 +117,16 @@ impl Nc {
     #[deprecated]
     #[doc(hidden)]
     pub unsafe fn without_altscreen<'a>() -> NcResult<&'a mut Nc> {
-        Self::with_flags(NcOptions::NO_ALTERNATE_SCREEN | NcOptions::SUPPRESS_BANNERS)
+        Self::with_flags(NcFlags::NoAlternateScreen | NcFlags::SuppressBanners)
     }
 
-    /// New notcurses context, expects `NcOptions::*` flags.
+    /// New notcurses context, expects [`NcFlags`].
     ///
     /// # Safety
     /// You must not create multiple `Nc` instances at the same time, on
     /// the same thread. You must [`stop`][Nc#method.stop] the current one
     /// before creating a new one.
-    pub unsafe fn with_flags<'a>(flags: u64) -> NcResult<&'a mut Nc> {
+    pub unsafe fn with_flags<'a>(flags: NcFlags) -> NcResult<&'a mut Nc> {
         Self::with_options(NcOptions::with_flags(flags))
     }
 
@@ -144,7 +147,7 @@ impl Nc {
     /// You must not create multiple `Nc` instances at the same time, on
     /// the same thread. You must [`stop`][Nc#method.stop] the current one
     /// before creating a new one.
-    pub unsafe fn with_debug<'a>(loglevel: NcLogLevel, flags: u64) -> NcResult<&'a mut Nc> {
+    pub unsafe fn with_debug<'a>(loglevel: NcLogLevel, flags: NcFlags) -> NcResult<&'a mut Nc> {
         Self::with_options(NcOptions::with_all_options(loglevel, 0, 0, 0, 0, flags))
     }
 
@@ -164,16 +167,16 @@ impl Nc {
     /// Returns the offset into `availcols` at which `cols` ought be output given
     /// the requirements of `align`.
     ///
-    /// Returns `-`[NcIntResult::MAX][crate::NcIntResult::MAX] if
+    /// Returns `-`[NCRESULT_MAX][c_api::NCRESULT_MAX] if
     /// [`NcAlign::Unaligned`].
     ///
     /// *C style function: [notcurses_align()][c_api::notcurses_align].*
-    pub fn align(availcols: NcDim, align: NcAlign, cols: NcDim) -> NcResult<NcDim> {
+    pub fn align(availcols: u32, align: NcAlign, cols: u32) -> NcResult<u32> {
         let res = c_api::notcurses_align(availcols, align, cols);
         error![
             res,
             &format!("NcPlane.valign({:?}, {})", align, cols),
-            res as NcDim
+            res as u32
         ]
     }
 
@@ -184,19 +187,19 @@ impl Nc {
     /// *C style function: [notcurses_at_yx()][c_api::notcurses_at_yx].*
     pub fn at_yx(
         &mut self,
-        y: NcDim,
-        x: NcDim,
+        y: u32,
+        x: u32,
         stylemask: &mut NcStyle,
         channels: &mut NcChannels,
     ) -> Option<String> {
-        let egc = unsafe { c_api::notcurses_at_yx(self, y, x, stylemask, channels) };
+        let egc = unsafe { c_api::notcurses_at_yx(self, y, x, stylemask.into(), &mut channels.0) };
         if egc.is_null() {
             return None;
         }
         Some(rstring_free![egc])
     }
 
-    /// Returns [`NcCapabilities`].
+    /// Returns the detected capabilities of the current terminal.
     ///
     /// *C style function: [notcurses_capabilities()][c_api::notcurses_capabilities].*
     pub fn capabilities(&self) -> NcCapabilities {
@@ -310,28 +313,28 @@ impl Nc {
     /// *C style function: [notcurses_check_pixel_support()][c_api::notcurses_check-pixel_support].*
     #[allow(clippy::wildcard_in_or_patterns)]
     pub fn check_pixel_support(&self) -> NcPixelImpl {
-        unsafe { c_api::notcurses_check_pixel_support(self) }
+        unsafe { c_api::notcurses_check_pixel_support(self) }.into()
     }
 
     /// Returns the default foreground color, if it is known.
     pub fn default_forekground(&self) -> Option<NcRgb> {
-        let mut fg: NcRgb = 0;
+        let mut fg = 0;
         let res = unsafe { c_api::notcurses_default_foreground(self, &mut fg) };
         if res == c_api::NCRESULT_ERR {
             None
         } else {
-            Some(fg)
+            Some(fg.into())
         }
     }
 
     /// Returns the default background color, if it is known.
     pub fn default_background(&self) -> Option<NcRgb> {
-        let mut bg: NcRgb = 0;
+        let mut bg = 0;
         let res = unsafe { c_api::notcurses_default_background(self, &mut bg) };
         if res == c_api::NCRESULT_ERR {
             None
         } else {
-            Some(bg)
+            Some(bg.into())
         }
     }
 
@@ -350,7 +353,7 @@ impl Nc {
     /// It is an error if `y`, `x` lies outside the standard plane.
     ///
     /// *C style function: [notcurses_cursor_enable()][c_api::notcurses_cursor_enable].*
-    pub fn cursor_enable(&mut self, y: NcDim, x: NcDim) -> NcResult<()> {
+    pub fn cursor_enable(&mut self, y: u32, x: u32) -> NcResult<()> {
         error![unsafe { c_api::notcurses_cursor_enable(self, y as i32, x as i32) }]
     }
 
@@ -459,7 +462,7 @@ impl Nc {
         if res == c_api::NCRESULT_ERR as u32 {
             Err(NcError::new_msg(&format!["Nc.get({:?})", time]))
         } else {
-            Ok(NcReceived::new(res))
+            Ok(NcReceived::from(res))
         }
     }
 
@@ -475,7 +478,7 @@ impl Nc {
         if res == c_api::NCRESULT_ERR {
             Err(NcError::new_msg("Nc.get_blocking()"))
         } else {
-            Ok(NcReceived::new(res as u32))
+            Ok(NcReceived::from(res as u32))
         }
     }
 
@@ -491,7 +494,7 @@ impl Nc {
         if res == c_api::NCRESULT_ERR {
             Err(NcError::new_msg("Nc.get_nblock()"))
         } else {
-            Ok(NcReceived::new(res as u32))
+            Ok(NcReceived::from(res as u32))
         }
     }
 
@@ -577,16 +580,16 @@ impl Nc {
     ///
     /// *(No equivalent C style function)*
     pub fn lex_styles(styles_str: &str) -> NcResult<NcStyle> {
-        let mut style = NcStyle::NOSTYLE;
+        let mut style = NcStyle::None;
         let mut errstr = String::new();
 
         for s in styles_str.split(' ') {
             match s.to_lowercase().as_str() {
-                "italic" => style.add(NcStyle::ITALIC),
-                "underline" => style.add(NcStyle::UNDERLINE),
-                "undercurl" => style.add(NcStyle::UNDERCURL),
-                "struck" => style.add(NcStyle::STRUCK),
-                "bold" => style.add(NcStyle::BOLD),
+                "italic" => style.add(NcStyle::Italic),
+                "underline" => style.add(NcStyle::Underline),
+                "undercurl" => style.add(NcStyle::Undercurl),
+                "struck" => style.add(NcStyle::Struck),
+                "bold" => style.add(NcStyle::Bold),
                 "none" => (),
                 _ => {
                     errstr.push_str(s);
@@ -625,7 +628,7 @@ impl Nc {
     ///
     /// *C style function: [notcurses_mice_disable()][c_api::notcurses_mice_disable].*
     pub fn mice_disable(&mut self) -> NcResult<()> {
-        self.mice_enable(NcMiceEvents::NO_EVENTS)
+        self.mice_enable(NcMiceEvents::None)
     }
 
     /// Enables mice events according to `eventmask`.
@@ -637,7 +640,7 @@ impl Nc {
     /// *C style function: [notcurses_mice_enable()][c_api::notcurses_mice_enable].*
     pub fn mice_enable(&mut self, eventmask: NcMiceEvents) -> NcResult<()> {
         error![
-            unsafe { c_api::notcurses_mice_enable(self, eventmask) },
+            unsafe { c_api::notcurses_mice_enable(self, eventmask.into()) },
             "Nc.mice_enable()"
         ]
     }
@@ -669,12 +672,12 @@ impl Nc {
     ///
     /// *C style function: [notcurses_refresh()][c_api::notcurses_refresh].*
     //
-    pub fn refresh(&mut self) -> NcResult<(NcDim, NcDim)> {
+    pub fn refresh(&mut self) -> NcResult<(u32, u32)> {
         let (mut y, mut x) = (0, 0);
         error![
             unsafe { c_api::notcurses_refresh(self, &mut y, &mut x) },
             "",
-            (y as NcDim, x as NcDim)
+            (y as u32, x as u32)
         ]
     }
 
@@ -722,8 +725,8 @@ impl Nc {
     // #[inline]
     // pub fn stddim_yx<'a>(
     //     &'a mut self,
-    //     y: &mut NcDim,
-    //     x: &mut NcDim,
+    //     y: &mut u32,
+    //     x: &mut u32,
     // ) -> NcResult<&'a mut NcPlane> {
     //     c_api::notcurses_stddim_yx(self, y, x)
     // }
@@ -735,8 +738,8 @@ impl Nc {
     // #[inline]
     // pub fn stddim_yx_const<'a>(
     //     &'a self,
-    //     y: &mut NcDim,
-    //     x: &mut NcDim,
+    //     y: &mut u32,
+    //     x: &mut u32,
     // ) -> NcResult<&'a NcPlane> {
     //     c_api::notcurses_stddim_yx_const(self, y, x)
     // }
@@ -791,13 +794,13 @@ impl Nc {
         let mut string = String::new();
         for s in style.to_vec() {
             string.push_str(match s {
-                NcStyle::ITALIC => "italic",
-                NcStyle::UNDERLINE => "underline",
-                NcStyle::UNDERCURL => "undercurl",
-                NcStyle::STRUCK => "struck",
-                NcStyle::BOLD => "bold",
+                NcStyle::Italic => "italic",
+                NcStyle::Underline => "underline",
+                NcStyle::Undercurl => "undercurl",
+                NcStyle::Struck => "struck",
+                NcStyle::Bold => "bold",
                 #[allow(unreachable_patterns)] // FIXME
-                NcStyle::NOSTYLE => "none",
+                NcStyle::None => "none",
                 _ => "none",
             });
             string.push(' ');
@@ -815,13 +818,13 @@ impl Nc {
     ///
     /// *C style function: [notcurses_supported_styles()][c_api::notcurses_supported_styles].*
     pub fn supported_styles(&self) -> NcStyle {
-        unsafe { c_api::notcurses_supported_styles(self) as NcStyle }
+        unsafe { c_api::notcurses_supported_styles(self).into() }
     }
 
     /// Returns our current idea of the terminal dimensions in rows and cols.
     ///
     /// *C style function: [notcurses_term_dim_yx()][c_api::notcurses_term_dim_yx].*
-    pub fn term_dim_yx(&self) -> (NcDim, NcDim) {
+    pub fn term_dim_yx(&self) -> (u32, u32) {
         c_api::notcurses_term_dim_yx(self)
     }
 
@@ -883,7 +886,7 @@ impl Nc {
         visual: Option<&NcVisual>,
         vopts: Option<&NcVisualOptions>,
     ) -> NcResult<NcVisualGeometry> {
-        let mut vg = NcVGeom::new();
+        let mut vg = c_api::NcVGeom::new();
 
         let v_ptr: *const NcVisual;
         if let Some(v) = visual {
@@ -912,12 +915,12 @@ impl Nc {
         // if an `NcVisual` is not provided, only `maxpixel_yx`, `cdim_yx` and
         // `scale_yx` can be non-zero.
         if visual.is_none() {
-            cdim_yx = Some((vg.cdimy as NcDim, vg.cdimx as NcDim));
-            scale_yx = Some((vg.scaley as NcDim, vg.scalex as NcDim));
+            cdim_yx = Some((vg.cdimy as u32, vg.cdimx as u32));
+            scale_yx = Some((vg.scaley as u32, vg.scalex as u32));
 
             // pixel blitter only is defined for Ncblitter::PIXEL
             if vg.blitter == NcBlitter::Pixel.into() {
-                maxpixel_yx = Some((vg.maxpixely as NcDim, vg.maxpixelx as NcDim));
+                maxpixel_yx = Some((vg.maxpixely as u32, vg.maxpixelx as u32));
             } else {
                 maxpixel_yx = None;
             }
@@ -930,7 +933,7 @@ impl Nc {
         } else {
             // `maxpixel_yx` only is defined for `Ncblitter`::PIXEL.
             if vg.blitter == NcBlitter::Pixel.into() {
-                maxpixel_yx = Some((vg.maxpixely as NcDim, vg.maxpixelx as NcDim));
+                maxpixel_yx = Some((vg.maxpixely as u32, vg.maxpixelx as u32));
             } else {
                 maxpixel_yx = None;
             }
@@ -940,35 +943,35 @@ impl Nc {
                 beg_yx = None;
                 len_yx = None;
             } else {
-                beg_yx = Some((vg.begy as NcDim, vg.begx as NcDim));
-                len_yx = Some((vg.leny as NcDim, vg.lenx as NcDim));
+                beg_yx = Some((vg.begy as u32, vg.begx as u32));
+                len_yx = Some((vg.leny as u32, vg.lenx as u32));
             }
 
             // valid values for the following fields can't be 0 either:
             if vg.pixy | vg.pixx == 0 {
                 pix_yx = None;
             } else {
-                pix_yx = Some((vg.pixy as NcDim, vg.pixx as NcDim));
+                pix_yx = Some((vg.pixy as u32, vg.pixx as u32));
             }
             if vg.cdimy | vg.cdimx == 0 {
                 cdim_yx = None;
             } else {
-                cdim_yx = Some((vg.cdimy as NcDim, vg.cdimx as NcDim));
+                cdim_yx = Some((vg.cdimy as u32, vg.cdimx as u32));
             }
             if vg.scaley | vg.scalex == 0 {
                 scale_yx = None;
             } else {
-                scale_yx = Some((vg.scaley as NcDim, vg.scalex as NcDim));
+                scale_yx = Some((vg.scaley as u32, vg.scalex as u32));
             }
             if vg.rpixy | vg.rpixx == 0 {
                 rpix_yx = None;
             } else {
-                rpix_yx = Some((vg.rpixy as NcDim, vg.rpixx as NcDim));
+                rpix_yx = Some((vg.rpixy as u32, vg.rpixx as u32));
             }
             if vg.rcelly | vg.rcellx == 0 {
                 rcell_yx = None;
             } else {
-                rcell_yx = Some((vg.rcelly as NcDim, vg.rcellx as NcDim));
+                rcell_yx = Some((vg.rcelly as u32, vg.rcellx as u32));
             }
         }
 
