@@ -268,7 +268,7 @@ pub use options::{NcPlaneOptions, NcPlaneOptionsBuilder};
 /// Methods:
 /// - [`NcAlpha`](#ncplane-methods-ncalphabits)
 /// - [`NcChannel` & `NcChannels`](#ncplane-methods-ncchannel)
-/// - [`NcComponent`, `NcRgb` & default color](#ncplane-methods-nccomponent-ncrgb--default-color)
+/// - [`NcRgb`, components & default color](#ncplane-methods-ncrgb-components--default-color)
 /// - [`NcStyle` & `NcPaletteIndex`](#ncplane-methods-ncstylemask--paletteindex)
 /// - [`NcCell` & strings](#ncplane-methods-nccell--strings)
 /// - [cursor](#ncplane-methods-cursor)
@@ -283,4 +283,4 @@ pub use options::{NcPlaneOptions, NcPlaneOptionsBuilder};
 /// [`NcPlane.render`]: crate::NcPlane#method.render
 /// [`NcPlane.rasterize`]: crate::NcPlane#method.render
 /// [`Nc.refresh`]: crate::Nc#method.refresh
-pub type NcPlane = crate::bindings::ffi::ncplane;
+pub type NcPlane = crate::c_api::ffi::ncplane;
