@@ -1,10 +1,12 @@
 //!
 
+use crate::c_api::ffi;
+
 mod builder;
-pub(crate) mod constants;
+pub(crate) mod c_api;
 pub use builder::NcPlaneOptionsBuilder;
 
-use crate::{c_api, NcAlign, NcDim, NcOffset, NcResizeCb};
+use crate::{NcAlign, NcResizeCb};
 
 use std::ptr::{null, null_mut};
 
@@ -27,28 +29,28 @@ use std::ptr::{null, null_mut};
 /// - [`margin_b`]: bottom margin (requires the [`MARGINALIZED`] flag).
 /// - [`margin_r`]: right margin (requires the [`MARGINALIZED`]).
 ///
-/// [`y`]: crate::c_api::ffi::ncplane_options#structfield.y
-/// [`x`]: crate::c_api::ffi::ncplane_options#structfield.x
-/// [`rows`]: crate::c_api::ffi::ncplane_options#structfield.rows
-/// [`cols`]: crate::c_api::ffi::ncplane_options#structfield.cols
-/// [`userptr`]: crate::c_api::ffi::ncplane_options#structfield.userptr
-/// [`name`]: crate::c_api::ffi::ncplane_options#structfield.name
-/// [`resizecb`]: crate::c_api::ffi::ncplane_options#structfield.resizecb
-/// [`flags`]: crate::c_api::ffi::ncplane_options#structfield.flags
-/// [`margin_b`]: crate::c_api::ffi::ncplane_options#structfield.margin_b
-/// [`margin_r`]: crate::c_api::ffi::ncplane_options#structfield.margin_r
+/// [`y`]: ffi::ncplane_options#structfield.y
+/// [`x`]: ffi::ncplane_options#structfield.x
+/// [`rows`]: ffi::ncplane_options#structfield.rows
+/// [`cols`]: ffi::ncplane_options#structfield.cols
+/// [`userptr`]: ffi::ncplane_options#structfield.userptr
+/// [`name`]: ffi::ncplane_options#structfield.name
+/// [`resizecb`]: ffi::ncplane_options#structfield.resizecb
+/// [`flags`]: ffi::ncplane_options#structfield.flags
+/// [`margin_b`]: ffi::ncplane_options#structfield.margin_b
+/// [`margin_r`]: ffi::ncplane_options#structfield.margin_r
 /// [`VERALIGNED`]:NcPlaneOptions#associatedconstant.VERALIGNED
 /// [`HORALIGNED`]: NcPlaneOptions#associatedconstant.HORALIGNED
 /// [`MARGINALIZED`]: NcPlaneOptions#associatedconstant.MARGINALIZED
 /// [`FIXED`]: NcPlaneOptions#associatedconstant.FIXED
 /// [`AUTOGROW`]: NcPlaneOptions#associatedconstant.AUTOGROW
 /// [`VSCROLL`]: NcPlaneOptions#associatedconstant.VSCROLL
-pub type NcPlaneOptions = crate::bindings::ffi::ncplane_options;
+pub type NcPlaneOptions = ffi::ncplane_options;
 
 /// # Constructors
 impl NcPlaneOptions {
     /// New NcPlaneOptions using the horizontal x.
-    pub fn new(y: NcOffset, x: NcOffset, rows: NcDim, cols: NcDim) -> Self {
+    pub fn new(y: i32, x: i32, rows: u32, cols: u32) -> Self {
         Self::with_flags(y, x, rows, cols, None, 0, 0, 0)
     }
 
@@ -63,20 +65,20 @@ impl NcPlaneOptions {
     }
 
     /// New NcPlaneOptions with horizontal alignment.
-    pub fn new_aligned(y: NcOffset, align: NcAlign, rows: NcDim, cols: NcDim) -> Self {
+    pub fn new_aligned(y: i32, align: NcAlign, rows: u32, cols: u32) -> Self {
         Self::with_flags_aligned(y, align, rows, cols, None, NcPlaneOptions::HORALIGNED)
     }
 
     /// New NcPlaneOptions, with flags.
     pub fn with_flags(
-        y: NcOffset,
-        x: NcOffset,
-        rows: NcDim,
-        cols: NcDim,
+        y: i32,
+        x: i32,
+        rows: u32,
+        cols: u32,
         resizecb: Option<NcResizeCb>,
         flags: u64,
-        margin_b: NcDim,
-        margin_r: NcDim,
+        margin_b: u32,
+        margin_r: u32,
     ) -> Self {
         NcPlaneOptions {
             y: y as i32,
@@ -85,7 +87,7 @@ impl NcPlaneOptions {
             cols,
             userptr: null_mut(),
             name: null(),
-            resizecb: c_api::ncresizecb_to_c(resizecb),
+            resizecb: crate::c_api::ncresizecb_to_c(resizecb),
             flags,
             margin_b,
             margin_r,
@@ -98,10 +100,10 @@ impl NcPlaneOptions {
     /// [`NcPlaneOptions::HORALIGNED`][NcPlaneOptions#associatedconstant.HORALIGNED]
     /// flag.
     pub fn with_flags_aligned(
-        y: NcOffset,
+        y: i32,
         align: NcAlign,
-        rows: NcDim,
-        cols: NcDim,
+        rows: u32,
+        cols: u32,
         resizecb: Option<NcResizeCb>,
         flags: u64,
     ) -> Self {
@@ -113,7 +115,7 @@ impl NcPlaneOptions {
             cols,
             userptr: null_mut(),
             name: null(),
-            resizecb: c_api::ncresizecb_to_c(resizecb),
+            resizecb: crate::c_api::ncresizecb_to_c(resizecb),
             flags,
             margin_b: 0,
             margin_r: 0,
