@@ -2,9 +2,9 @@
 
 // TOC:
 // - Alpha
-// - NcChannel
-// - NcComponent
-// - NcRgb
+// - NcChannel_u32
+// - RGB components
+// - NcRgb_u32
 // - Default
 // - put & print
 // - movement, size & alignment
@@ -19,9 +19,11 @@ use core::ptr::null_mut;
 use std::ffi::CString;
 
 use crate::{
-    c_api::{self, nccell_release, NCRESULT_ERR},
-    cstring, NcAlign, NcAlpha, NcBoxMask, NcCell, NcChannel, NcChannels, NcComponent, NcDim,
-    NcIntResult, NcIntResultApi, NcOffset, NcPlane, NcRgb, NcStyle,
+    c_api::{
+        self, nccell_release, NcChannel_u32, NcChannels_u64, NcResult_i32, NcRgb_u32, NcStyle_u16,
+        NCRESULT_ERR, NCRESULT_OK,
+    },
+    cstring, NcAlign, NcAlpha, NcBoxMask, NcCell, NcPlane,
 };
 
 // Alpha -----------------------------------------------------------------------
@@ -42,105 +44,105 @@ pub fn ncplane_bg_alpha(plane: &NcPlane) -> NcAlpha {
     c_api::ncchannels_bg_alpha(ncplane_channels(plane))
 }
 
-// NcChannel -------------------------------------------------------------------
+// NcChannel_u32 ---------------------------------------------------------------
 
-/// Gets the foreground [`NcChannel`] from an [`NcPlane`].
+/// Gets the foreground [`NcChannel_u32`] from an [`NcPlane`].
 ///
 /// *Method: NcPlane.[fchannel()][NcPlane#method.fchannel].*
 #[inline]
-pub fn ncplane_fchannel(plane: &NcPlane) -> NcChannel {
+pub fn ncplane_fchannel(plane: &NcPlane) -> NcChannel_u32 {
     c_api::ncchannels_fchannel(ncplane_channels(plane))
 }
 
-/// Gets the background [`NcChannel`] from an [`NcPlane`].
+/// Gets the background [`NcChannel_u32`] from an [`NcPlane`].
 ///
 /// *Method: NcPlane.[bchannel()][NcPlane#method.bchannel].*
 #[inline]
-pub fn ncplane_bchannel(plane: &NcPlane) -> NcChannel {
+pub fn ncplane_bchannel(plane: &NcPlane) -> NcChannel_u32 {
     c_api::ncchannels_bchannel(ncplane_channels(plane))
 }
 
-/// Sets the foreground [`NcChannel`] on an [`NcPlane`],
-/// and returns the new [`NcChannels`].
+/// Sets the foreground [`NcChannel_u32`] on an [`NcPlane`],
+/// and returns the new [`NcChannels_u64`].
 ///
 /// *Method: NcPlane.[set_fchannel()][NcPlane#method.set_fchannel].*
 #[inline]
-pub fn ncplane_set_fchannel(plane: &mut NcPlane, channel: NcChannel) -> NcChannels {
+pub fn ncplane_set_fchannel(plane: &mut NcPlane, channel: NcChannel_u32) -> NcChannels_u64 {
     unsafe { c_api::ffi::ncplane_set_fchannel(plane, channel) }
 }
 
-/// Sets the background [`NcChannel`] on an [`NcPlane`],
-/// and returns the new [`NcChannels`].
+/// Sets the background [`NcChannel_u32`] on an [`NcPlane`],
+/// and returns the new [`NcChannels_u64`].
 ///
 /// *Method: NcPlane.[set_bchannel()][NcPlane#method.set_bchannel].*
 #[inline]
-pub fn ncplane_set_bchannel(plane: &mut NcPlane, channel: NcChannel) -> NcChannels {
+pub fn ncplane_set_bchannel(plane: &mut NcPlane, channel: NcChannel_u32) -> NcChannels_u64 {
     unsafe { c_api::ffi::ncplane_set_bchannel(plane, channel) }
 }
 
-/// Gets the [`NcChannels`] of an [`NcPlane`].
+/// Gets the [`NcChannels_u64`] of an [`NcPlane`].
 ///
 /// *Method: NcPlane.[channels()][NcPlane#method.channels].*
 #[inline]
-pub fn ncplane_channels(plane: &NcPlane) -> NcChannels {
+pub fn ncplane_channels(plane: &NcPlane) -> NcChannels_u64 {
     unsafe { c_api::ffi::ncplane_channels(plane) }
 }
 
-/// Sets the [`NcChannels`] of an [`NcPlane`].
+/// Sets the [`NcChannels_u64`] of an [`NcPlane`].
 ///
 /// *Method: NcPlane.[set_channels()][NcPlane#method.set_channels].*
 #[inline]
-pub fn ncplane_set_channels(plane: &mut NcPlane, channels: NcChannels) {
+pub fn ncplane_set_channels(plane: &mut NcPlane, channels: NcChannels_u64) {
     unsafe {
         c_api::ffi::ncplane_set_channels(plane, channels);
     }
 }
 
-// NcComponent ---------------------------------------------------------------------
+// RGB components --------------------------------------------------------------
 
-/// Gets the foreground RGB [`NcComponent`]s from an [`NcPlane`].
-/// and returns the background [`NcChannel`].
+/// Gets the foreground RGB components from an [`NcPlane`].
+/// and returns the background [`NcChannel_u32`].
 ///
 /// *Method: NcPlane.[fg_rgb8()][NcPlane#method.fg_rgb8].*
 #[inline]
 pub fn ncplane_fg_rgb8(
     plane: &NcPlane,
-    red: &mut NcComponent,
-    green: &mut NcComponent,
-    blue: &mut NcComponent,
-) -> NcChannel {
+    red: &mut u8,
+    green: &mut u8,
+    blue: &mut u8,
+) -> NcChannel_u32 {
     c_api::ncchannels_fg_rgb8(ncplane_channels(plane), red, green, blue)
 }
 
-/// Gets the background RGB [`NcComponent`]s from an [`NcPlane`],
-/// and returns the background [`NcChannel`].
+/// Gets the background RGB componentss from an [`NcPlane`],
+/// and returns the background [`NcChannel_u32`].
 ///
 /// *Method: NcPlane.[bg_rgb8()][NcPlane#method.bg_rgb8].*
 #[inline]
 pub fn ncplane_bg_rgb8(
     plane: &NcPlane,
-    red: &mut NcComponent,
-    green: &mut NcComponent,
-    blue: &mut NcComponent,
-) -> NcChannel {
+    red: &mut u8,
+    green: &mut u8,
+    blue: &mut u8,
+) -> NcChannel_u32 {
     c_api::ncchannels_bg_rgb8(ncplane_channels(plane), red, green, blue)
 }
 
-// NcRgb -----------------------------------------------------------------------
+// NcRgb_u32 -----------------------------------------------------------------------
 
-/// Gets the foreground [`NcRgb`] from an [`NcPlane`], shifted to LSBs.
+/// Gets the foreground [`NcRgb_u32`] from an [`NcPlane`], shifted to LSBs.
 ///
 /// *Method: NcPlane.[fg_rgb()][NcPlane#method.fg_rgb].*
 #[inline]
-pub fn ncplane_fg_rgb(plane: &NcPlane) -> NcRgb {
+pub fn ncplane_fg_rgb(plane: &NcPlane) -> NcRgb_u32 {
     c_api::ncchannels_fg_rgb(ncplane_channels(plane))
 }
 
-/// Gets the background [`NcRgb`] from an [`NcPlane`], shifted to LSBs.
+/// Gets the background [`NcRgb_u32`] from an [`NcPlane`], shifted to LSBs.
 ///
 /// *Method: NcPlane.[bg_rgb()][NcPlane#method.bg_rgb].*
 #[inline]
-pub fn ncplane_bg_rgb(plane: &NcPlane) -> NcRgb {
+pub fn ncplane_bg_rgb(plane: &NcPlane) -> NcRgb_u32 {
     c_api::ncchannels_bg_rgb(ncplane_channels(plane))
 }
 
@@ -163,50 +165,50 @@ pub fn ncplane_bg_default_p(plane: &NcPlane) -> bool {
 }
 
 /// Marks both the foreground and background as using the "default color",
-/// and returns the new [`NcChannels`].
+/// and returns the new [`NcChannels_u64`].
 ///
 /// *Method: NcPlane.[set_default()][NcPlane#method.set_default].*
 //
 // Not in the C API.
 #[inline]
-pub fn ncplane_set_default(plane: &mut NcPlane) -> NcChannels {
+pub fn ncplane_set_default(plane: &mut NcPlane) -> NcChannels_u64 {
     let channels = c_api::ncchannels_set_default(&mut ncplane_channels(plane));
     ncplane_set_channels(plane, channels);
     channels
 }
 
 /// Marks both the foreground and background as NOT using the "default color",
-/// and returns the new [`NcChannels`].
+/// and returns the new [`NcChannels_u64`].
 ///
 /// *Method: NcPlane.[set_not_default()][NcPlane#method.set_not_default].*
 //
 // Not in the C API.
 #[inline]
-pub fn ncplane_set_not_default(plane: &mut NcPlane) -> NcChannels {
+pub fn ncplane_set_not_default(plane: &mut NcPlane) -> NcChannels_u64 {
     let channels = c_api::ncchannels_set_not_default(&mut ncplane_channels(plane));
     c_api::ncplane_set_channels(plane, channels);
     channels
 }
 
 /// Marks the foreground as NOT using the "default color",
-/// and returns the new [`NcChannels`].
+/// and returns the new [`NcChannels_u64`].
 ///
 /// *Method: NcPlane.[set_fg_not_default()][NcPlane#method.set_fg_not_default].*
 //
 // Not in the C API.
 #[inline]
-pub fn ncplane_set_fg_not_default(plane: &NcPlane) -> NcChannels {
+pub fn ncplane_set_fg_not_default(plane: &NcPlane) -> NcChannels_u64 {
     c_api::ncchannels_set_fg_not_default(&mut ncplane_channels(plane))
 }
 
 /// Marks the background as NOT using the "default color",
-/// and returns the new [`NcChannels`].
+/// and returns the new [`NcChannels_u64`].
 ///
 /// *Method: NcPlane.[set_bg_not_default()][NcPlane#method.set_bg_not_default].*
 //
 // Not in the C API.
 #[inline]
-pub fn ncplane_set_bg_not_default(plane: &NcPlane) -> NcChannels {
+pub fn ncplane_set_bg_not_default(plane: &NcPlane) -> NcChannels_u64 {
     c_api::ncchannels_set_bg_not_default(&mut ncplane_channels(plane))
 }
 
@@ -224,7 +226,7 @@ pub fn ncplane_set_bg_not_default(plane: &NcPlane) -> NcChannels {
 ///
 /// *Method: NcPlane.[putc()][NcPlane#method.putc].*
 #[inline]
-pub fn ncplane_putc(plane: &mut NcPlane, cell: &NcCell) -> NcIntResult {
+pub fn ncplane_putc(plane: &mut NcPlane, cell: &NcCell) -> NcResult_i32 {
     unsafe { c_api::ncplane_putc_yx(plane, -1, -1, cell) }
 }
 
@@ -238,11 +240,11 @@ pub fn ncplane_putc(plane: &mut NcPlane, cell: &NcCell) -> NcIntResult {
 ///
 /// *Method: NcPlane.[putchar()][NcPlane#method.putchar].*
 #[inline]
-pub fn ncplane_putchar(plane: &mut NcPlane, ch: char) -> NcIntResult {
+pub fn ncplane_putchar(plane: &mut NcPlane, ch: char) -> NcResult_i32 {
     unsafe {
         let cell = NcCell::from_char(plane, ch);
         if cell.is_err() {
-            return NcIntResult::ERR;
+            return NCRESULT_ERR;
         }
         c_api::ncplane_putc_yx(plane, -1, -1, &cell.unwrap())
     }
@@ -258,11 +260,11 @@ pub fn ncplane_putchar(plane: &mut NcPlane, ch: char) -> NcIntResult {
 ///
 /// *Method: NcPlane.[putchar_yx()][NcPlane#method.putchar_yx].*
 #[inline]
-pub fn ncplane_putchar_yx(plane: &mut NcPlane, y: NcDim, x: NcDim, ch: char) -> NcIntResult {
+pub fn ncplane_putchar_yx(plane: &mut NcPlane, y: u32, x: u32, ch: char) -> NcResult_i32 {
     unsafe {
         let cell = NcCell::from_char(plane, ch);
         if cell.is_err() {
-            return NcIntResult::ERR;
+            return NCRESULT_ERR;
         }
         c_api::ncplane_putc_yx(plane, y as i32, x as i32, &cell.unwrap())
     }
@@ -278,7 +280,7 @@ pub fn ncplane_putchar_yx(plane: &mut NcPlane, y: NcDim, x: NcDim, ch: char) ->
 ///
 /// *Method: NcPlane.[putchar_stained()][NcPlane#method.putchar_stained].*
 #[inline]
-pub fn ncplane_putchar_stained(plane: &mut NcPlane, ch: char) -> NcIntResult {
+pub fn ncplane_putchar_stained(plane: &mut NcPlane, ch: char) -> NcResult_i32 {
     ncplane_putstr_stained(plane, &ch.to_string())
 }
 
@@ -296,7 +298,7 @@ pub fn ncplane_putchar_stained(plane: &mut NcPlane, ch: char) -> NcIntResult {
 ///
 /// *Method: NcPlane.[putegc()][NcPlane#method.putegc].*
 #[inline]
-pub fn ncplane_putegc(plane: &mut NcPlane, egc: &str, sbytes: Option<&mut usize>) -> NcIntResult {
+pub fn ncplane_putegc(plane: &mut NcPlane, egc: &str, sbytes: Option<&mut usize>) -> NcResult_i32 {
     let sbytes_ptr;
     if let Some(sb) = sbytes {
         sbytes_ptr = sb as *mut _;
@@ -323,11 +325,11 @@ pub fn ncplane_putegc(plane: &mut NcPlane, egc: &str, sbytes: Option<&mut usize>
 #[inline]
 pub fn ncplane_putegc_yx(
     plane: &mut NcPlane,
-    y: Option<NcDim>,
-    x: Option<NcDim>,
+    y: Option<u32>,
+    x: Option<u32>,
     egc: &str,
     sbytes: Option<&mut usize>,
-) -> NcIntResult {
+) -> NcResult_i32 {
     let sbytes_ptr;
     if let Some(sb) = sbytes {
         sbytes_ptr = sb as *mut _;
@@ -338,8 +340,8 @@ pub fn ncplane_putegc_yx(
     unsafe {
         c_api::ffi::ncplane_putegc_yx(
             plane,
-            y.unwrap_or(NcDim::MAX) as i32,
-            x.unwrap_or(NcDim::MAX) as i32,
+            y.unwrap_or(u32::MAX) as i32,
+            x.unwrap_or(u32::MAX) as i32,
             cstring![egc],
             sbytes_ptr,
         )
@@ -364,7 +366,7 @@ pub fn ncplane_putegc_stained(
     plane: &mut NcPlane,
     egc: &str,
     sbytes: Option<&mut usize>,
-) -> NcIntResult {
+) -> NcResult_i32 {
     let sbytes_ptr;
     if let Some(sb) = sbytes {
         sbytes_ptr = sb as *mut _;
@@ -388,7 +390,7 @@ pub fn ncplane_putegc_stained(
 ///
 /// *Method: NcPlane.[putstr()][NcPlane#method.putstr].*
 #[inline]
-pub fn ncplane_putstr(plane: &mut NcPlane, string: &str) -> NcIntResult {
+pub fn ncplane_putstr(plane: &mut NcPlane, string: &str) -> NcResult_i32 {
     ncplane_putstr_yx(plane, None, None, string)
 }
 
@@ -407,10 +409,10 @@ pub fn ncplane_putstr(plane: &mut NcPlane, string: &str) -> NcIntResult {
 #[inline]
 pub fn ncplane_putstr_yx(
     plane: &mut NcPlane,
-    y: Option<NcDim>,
-    x: Option<NcDim>,
+    y: Option<u32>,
+    x: Option<u32>,
     string: &str,
-) -> NcIntResult {
+) -> NcResult_i32 {
     let cstring = CString::new(string).unwrap();
     let mut cstring_ptr = cstring.as_ptr();
 
@@ -422,8 +424,8 @@ pub fn ncplane_putstr_yx(
         let cols = unsafe {
             c_api::ffi::ncplane_putegc_yx(
                 plane,
-                y.unwrap_or(NcDim::MAX) as i32,
-                x.unwrap_or(NcDim::MAX) as i32,
+                y.unwrap_or(u32::MAX) as i32,
+                x.unwrap_or(u32::MAX) as i32,
                 cstring_ptr,
                 &mut wcs,
             )
@@ -461,10 +463,10 @@ pub fn ncplane_putstr_yx(
 #[inline]
 pub fn ncplane_putstr_aligned(
     plane: &mut NcPlane,
-    y: Option<NcDim>,
+    y: Option<u32>,
     align: NcAlign,
     string: &str,
-) -> NcIntResult {
+) -> NcResult_i32 {
     let (mut validbytes, mut validwidth) = (0, 0);
 
     // we'll want to do the partial write if there's an error somewhere within
@@ -472,11 +474,11 @@ pub fn ncplane_putstr_aligned(
         c_api::ncstrwidth(cstring![string], &mut validbytes, &mut validwidth);
     }
 
-    let xpos = ncplane_halign(plane, align, validwidth as NcDim);
+    let xpos = ncplane_halign(plane, align, validwidth as u32);
     if xpos < 0 {
         NCRESULT_ERR
     } else {
-        ncplane_putstr_yx(plane, y, Some(xpos as NcDim), string)
+        ncplane_putstr_yx(plane, y, Some(xpos as u32), string)
     }
 }
 
@@ -493,7 +495,7 @@ pub fn ncplane_putstr_aligned(
 ///
 /// *Method: NcPlane.[putstr_stained()][NcPlane#method.putstr_stained].*
 #[inline]
-pub fn ncplane_putstr_stained(plane: &mut NcPlane, string: &str) -> NcIntResult {
+pub fn ncplane_putstr_stained(plane: &mut NcPlane, string: &str) -> NcResult_i32 {
     let cstring = CString::new(string).unwrap();
     let mut cstring_ptr = cstring.as_ptr();
 
@@ -530,11 +532,11 @@ pub fn ncplane_putstr_stained(plane: &mut NcPlane, string: &str) -> NcIntResult
 #[inline]
 pub fn ncplane_putnstr_yx(
     plane: &mut NcPlane,
-    y: Option<NcDim>,
-    x: Option<NcDim>,
+    y: Option<u32>,
+    x: Option<u32>,
     num_bytes: usize,
     string: &str,
-) -> NcIntResult {
+) -> NcResult_i32 {
     let cstring = CString::new(string).unwrap();
     let cstring_bytes_len = cstring.as_bytes().len();
     let cstring_ptr = cstring.as_ptr();
@@ -547,8 +549,8 @@ pub fn ncplane_putnstr_yx(
         let cols = unsafe {
             c_api::ffi::ncplane_putegc_yx(
                 plane,
-                y.unwrap_or(NcDim::MAX) as i32,
-                x.unwrap_or(NcDim::MAX) as i32,
+                y.unwrap_or(u32::MAX) as i32,
+                x.unwrap_or(u32::MAX) as i32,
                 cstring_ptr.add(offset),
                 &mut wcs,
             )
@@ -583,7 +585,7 @@ pub fn ncplane_putnstr_yx(
 ///
 /// *Method: NcPlane.[putnstr()][NcPlane#method.putnstr].*
 #[inline]
-pub fn ncplane_putnstr(plane: &mut NcPlane, num_bytes: usize, string: &str) -> NcIntResult {
+pub fn ncplane_putnstr(plane: &mut NcPlane, num_bytes: usize, string: &str) -> NcResult_i32 {
     c_api::ncplane_putnstr_yx(plane, None, None, num_bytes, string)
 }
 
@@ -598,7 +600,7 @@ pub fn ncplane_putnstr(plane: &mut NcPlane, num_bytes: usize, string: &str) -> N
 ///
 /// *Method: NcPlane.[move_rel()][NcPlane#method.move_rel].*
 #[inline]
-pub fn ncplane_moverel(plane: &mut NcPlane, rows: NcOffset, cols: NcOffset) -> NcIntResult {
+pub fn ncplane_moverel(plane: &mut NcPlane, rows: i32, cols: i32) -> NcResult_i32 {
     let (mut orig_y, mut orig_x) = (0, 0);
     unsafe {
         c_api::ncplane_yx(plane, &mut orig_y, &mut orig_x);
@@ -662,11 +664,11 @@ pub fn ncplane_move_family_bottom(plane: &mut NcPlane) {
 ///
 /// *Method: NcPlane.[dim_x()][NcPlane#method.dim_x].*
 #[inline]
-pub fn ncplane_dim_x(plane: &NcPlane) -> NcDim {
+pub fn ncplane_dim_x(plane: &NcPlane) -> u32 {
     unsafe {
         let mut x = 0;
         c_api::ncplane_dim_yx(plane, null_mut(), &mut x);
-        x as NcDim
+        x as u32
     }
 }
 
@@ -674,12 +676,11 @@ pub fn ncplane_dim_x(plane: &NcPlane) -> NcDim {
 ///
 /// *Method: NcPlane.[dim_y()][NcPlane#method.dim_y].*
 #[inline]
-#[inline]
-pub fn ncplane_dim_y(plane: &NcPlane) -> NcDim {
+pub fn ncplane_dim_y(plane: &NcPlane) -> u32 {
     unsafe {
         let mut y = 0;
         c_api::ncplane_dim_yx(plane, &mut y, null_mut());
-        y as NcDim
+        y as u32
     }
 }
 
@@ -688,7 +689,7 @@ pub fn ncplane_dim_y(plane: &NcPlane) -> NcDim {
 ///
 /// *Method: NcPlane.[resize_simple()][NcPlane#method.resize_simple].*
 #[inline]
-pub fn ncplane_resize_simple(plane: &mut NcPlane, len_y: NcDim, len_x: NcDim) -> NcIntResult {
+pub fn ncplane_resize_simple(plane: &mut NcPlane, len_y: u32, len_x: u32) -> NcResult_i32 {
     let (mut old_y, mut old_x) = (0, 0);
     unsafe {
         c_api::ncplane_dim_yx(plane, &mut old_y, &mut old_x);
@@ -712,8 +713,8 @@ pub fn ncplane_resize_simple(plane: &mut NcPlane, len_y: NcDim, len_x: NcDim) ->
             plane,
             0,
             0,
-            keep_len_y as NcDim,
-            keep_len_x as NcDim,
+            keep_len_y as u32,
+            keep_len_x as u32,
             0,
             0,
             len_y,
@@ -725,24 +726,24 @@ pub fn ncplane_resize_simple(plane: &mut NcPlane, len_y: NcDim, len_x: NcDim) ->
 /// Returns the column at which `numcols` columns ought start in order to be
 /// aligned according to `align` within the `plane`.
 ///
-/// Returns `-`[`NcIntResult::MAX`][crate::NcIntResult::MAX] if
+/// Returns `-`[`NCRESULT_MAX`][c_api::NCRESULT_MAX] if
 /// [NcAlign::Unaligned].
 ///
 /// *Method: NcPlane.[halign()][NcPlane#method.halign].*
 #[inline]
-pub fn ncplane_halign(plane: &NcPlane, align: NcAlign, numcols: NcDim) -> NcIntResult {
+pub fn ncplane_halign(plane: &NcPlane, align: NcAlign, numcols: u32) -> NcResult_i32 {
     c_api::notcurses_align(ncplane_dim_x(plane), align, numcols)
 }
 
 /// Returns the row at which `numrows` rows ought start in order to be aligned
 /// according to `align` within this NcPlane.
 ///
-/// Returns `-`[`NcIntResult::MAX`][crate::NcIntResult::MAX] if
+/// Returns `-`[`NCRESULT_MAX`][c_api::NCRESULT_MAX] if
 /// [NcAlign::Unaligned].
 ///
 /// *Method: NcPlane.[valign()][NcPlane#method.valign].*
 #[inline]
-pub fn ncplane_valign(plane: &NcPlane, align: NcAlign, numrows: NcDim) -> NcIntResult {
+pub fn ncplane_valign(plane: &NcPlane, align: NcAlign, numrows: u32) -> NcResult_i32 {
     c_api::notcurses_align(ncplane_dim_y(plane), align, numrows)
 }
 
@@ -759,7 +760,7 @@ pub fn ncplane_valign(plane: &NcPlane, align: NcAlign, numrows: NcDim) -> NcIntR
 ///
 /// *Method: NcPlane.[hline()][NcPlane#method.hline].*
 #[inline]
-pub fn ncplane_hline(plane: &mut NcPlane, cell: &NcCell, len: NcDim) -> NcIntResult {
+pub fn ncplane_hline(plane: &mut NcPlane, cell: &NcCell, len: u32) -> NcResult_i32 {
     unsafe { c_api::ncplane_hline_interp(plane, cell, len, cell.channels, cell.channels) }
 }
 
@@ -774,7 +775,7 @@ pub fn ncplane_hline(plane: &mut NcPlane, cell: &NcCell, len: NcDim) -> NcIntRes
 ///
 /// *Method: NcPlane.[vline()][NcPlane#method.vline].*
 #[inline]
-pub fn ncplane_vline(plane: &mut NcPlane, cell: &NcCell, len: NcDim) -> NcIntResult {
+pub fn ncplane_vline(plane: &mut NcPlane, cell: &NcCell, len: u32) -> NcResult_i32 {
     unsafe { c_api::ncplane_vline_interp(plane, cell, len, cell.channels, cell.channels) }
 }
 
@@ -793,7 +794,7 @@ pub fn ncplane_perimeter(
     hline: &NcCell,
     vline: &NcCell,
     boxmask: NcBoxMask,
-) -> NcIntResult {
+) -> NcResult_i32 {
     unsafe {
         c_api::ncplane_cursor_move_yx(plane, 0, 0);
         let (mut dimy, mut dimx) = (0, 0);
@@ -806,8 +807,8 @@ pub fn ncplane_perimeter(
             lr,
             hline,
             vline,
-            dimy as NcDim,
-            dimx as NcDim,
+            dimy as u32,
+            dimx as u32,
             boxmask,
         )
     }
@@ -819,12 +820,12 @@ pub fn ncplane_perimeter(
 #[inline]
 pub fn ncplane_perimeter_double(
     plane: &mut NcPlane,
-    stylemask: NcStyle,
-    channels: NcChannels,
+    stylemask: NcStyle_u16,
+    channels: NcChannels_u64,
     boxmask: NcBoxMask,
-) -> NcIntResult {
-    if unsafe { c_api::ncplane_cursor_move_yx(plane, 0, 0) } != NcIntResult::OK {
-        return NcIntResult::ERR;
+) -> NcResult_i32 {
+    if unsafe { c_api::ncplane_cursor_move_yx(plane, 0, 0) } != NCRESULT_OK {
+        return NCRESULT_ERR;
     }
     let (mut dimy, mut dimx) = (0, 0);
     unsafe {
@@ -838,9 +839,9 @@ pub fn ncplane_perimeter_double(
     let mut vl = NcCell::new();
     if c_api::nccells_double_box(
         plane, stylemask, channels, &mut ul, &mut ur, &mut ll, &mut lr, &mut hl, &mut vl,
-    ) != NcIntResult::OK
+    ) != NCRESULT_OK
     {
-        return NcIntResult::ERR;
+        return NCRESULT_ERR;
     }
     let ret = ncplane_box_sized(
         plane,
@@ -850,8 +851,8 @@ pub fn ncplane_perimeter_double(
         &lr,
         &hl,
         &vl,
-        dimy as NcDim,
-        dimx as NcDim,
+        dimy as u32,
+        dimx as u32,
         boxmask,
     );
     unsafe {
@@ -871,12 +872,12 @@ pub fn ncplane_perimeter_double(
 #[inline]
 pub fn ncplane_perimeter_rounded(
     plane: &mut NcPlane,
-    stylemask: NcStyle,
-    channels: NcChannels,
+    stylemask: NcStyle_u16,
+    channels: NcChannels_u64,
     boxmask: NcBoxMask,
-) -> NcIntResult {
-    if unsafe { c_api::ncplane_cursor_move_yx(plane, 0, 0) } != NcIntResult::OK {
-        return NcIntResult::ERR;
+) -> NcResult_i32 {
+    if unsafe { c_api::ncplane_cursor_move_yx(plane, 0, 0) } != NCRESULT_OK {
+        return NCRESULT_ERR;
     }
     let (mut dimy, mut dimx) = (0, 0);
     unsafe {
@@ -890,9 +891,9 @@ pub fn ncplane_perimeter_rounded(
     let mut vl = NcCell::new();
     if c_api::nccells_rounded_box(
         plane, stylemask, channels, &mut ul, &mut ur, &mut ll, &mut lr, &mut hl, &mut vl,
-    ) != NcIntResult::OK
+    ) != NCRESULT_OK
     {
-        return NcIntResult::ERR;
+        return NCRESULT_ERR;
     }
     let ret = ncplane_box_sized(
         plane,
@@ -902,8 +903,8 @@ pub fn ncplane_perimeter_rounded(
         &lr,
         &hl,
         &vl,
-        dimy as NcDim,
-        dimx as NcDim,
+        dimy as u32,
+        dimx as u32,
         boxmask,
     );
     unsafe {
@@ -925,14 +926,14 @@ pub fn ncplane_perimeter_rounded(
 #[inline]
 pub fn ncplane_ascii_box(
     plane: &mut NcPlane,
-    stylemask: NcStyle,
-    channels: NcChannels,
-    end_y: NcDim,
-    end_x: NcDim,
+    stylemask: NcStyle_u16,
+    channels: NcChannels_u64,
+    end_y: u32,
+    end_x: u32,
     boxmask: NcBoxMask,
-) -> NcIntResult {
+) -> NcResult_i32 {
     #[allow(unused_assignments)]
-    let mut ret = NcIntResult::OK;
+    let mut ret = NCRESULT_OK;
 
     let mut ul = NcCell::new();
     let mut ur = NcCell::new();
@@ -945,8 +946,19 @@ pub fn ncplane_ascii_box(
         ret = c_api::nccells_ascii_box(
             plane, stylemask, channels, &mut ul, &mut ur, &mut ll, &mut lr, &mut hl, &mut vl,
         );
-        if ret == NcIntResult::OK {
-            ret = c_api::ncplane_box(plane, &ul, &ur, &ll, &lr, &hl, &vl, end_y, end_x, boxmask);
+        if ret == NCRESULT_OK {
+            ret = c_api::ncplane_box(
+                plane,
+                &ul,
+                &ur,
+                &ll,
+                &lr,
+                &hl,
+                &vl,
+                end_y,
+                end_x,
+                boxmask.into(),
+            );
         }
 
         nccell_release(plane, &mut ul);
@@ -976,10 +988,10 @@ pub fn ncplane_box_sized(
     lr: &NcCell,
     hline: &NcCell,
     vline: &NcCell,
-    len_y: NcDim,
-    len_x: NcDim,
+    len_y: u32,
+    len_x: u32,
     boxmask: NcBoxMask,
-) -> NcIntResult {
+) -> NcResult_i32 {
     let (mut y, mut x) = (0, 0);
     unsafe {
         c_api::ncplane_cursor_yx(plane, &mut y, &mut x);
@@ -991,9 +1003,9 @@ pub fn ncplane_box_sized(
             lr,
             hline,
             vline,
-            (y + len_y - 1) as NcDim,
-            (x + len_x - 1) as NcDim,
-            boxmask,
+            (y + len_y - 1) as u32,
+            (x + len_x - 1) as u32,
+            boxmask.into(),
         )
     }
 }
@@ -1005,14 +1017,14 @@ pub fn ncplane_box_sized(
 #[inline]
 pub fn ncplane_double_box(
     plane: &mut NcPlane,
-    stylemask: NcStyle,
-    channels: NcChannels,
-    end_y: NcDim,
-    end_x: NcDim,
+    stylemask: NcStyle_u16,
+    channels: NcChannels_u64,
+    end_y: u32,
+    end_x: u32,
     boxmask: NcBoxMask,
-) -> NcIntResult {
+) -> NcResult_i32 {
     #[allow(unused_assignments)]
-    let mut ret = NcIntResult::OK;
+    let mut ret = NCRESULT_OK;
 
     let mut ul = NcCell::new();
     let mut ur = NcCell::new();
@@ -1025,8 +1037,19 @@ pub fn ncplane_double_box(
         ret = c_api::nccells_double_box(
             plane, stylemask, channels, &mut ul, &mut ur, &mut ll, &mut lr, &mut hl, &mut vl,
         );
-        if ret == NcIntResult::OK {
-            ret = c_api::ncplane_box(plane, &ul, &ur, &ll, &lr, &hl, &vl, end_y, end_x, boxmask);
+        if ret == NCRESULT_OK {
+            ret = c_api::ncplane_box(
+                plane,
+                &ul,
+                &ur,
+                &ll,
+                &lr,
+                &hl,
+                &vl,
+                end_y,
+                end_x,
+                boxmask.into(),
+            );
         }
 
         nccell_release(plane, &mut ul);
@@ -1045,12 +1068,12 @@ pub fn ncplane_double_box(
 #[inline]
 pub fn ncplane_double_box_sized(
     plane: &mut NcPlane,
-    stylemask: NcStyle,
-    channels: NcChannels,
-    len_y: NcDim,
-    len_x: NcDim,
+    stylemask: NcStyle_u16,
+    channels: NcChannels_u64,
+    len_y: u32,
+    len_x: u32,
     boxmask: NcBoxMask,
-) -> NcIntResult {
+) -> NcResult_i32 {
     let (mut y, mut x) = (0, 0);
     unsafe {
         c_api::ncplane_cursor_yx(plane, &mut y, &mut x);
@@ -1059,8 +1082,8 @@ pub fn ncplane_double_box_sized(
         plane,
         stylemask,
         channels,
-        y as NcDim + len_y - 1,
-        x as NcDim + len_x - 1,
+        y as u32 + len_y - 1,
+        x as u32 + len_x - 1,
         boxmask,
     )
 }
@@ -1072,14 +1095,14 @@ pub fn ncplane_double_box_sized(
 #[inline]
 pub fn ncplane_rounded_box(
     plane: &mut NcPlane,
-    stylemask: NcStyle,
-    channels: NcChannels,
-    end_y: NcDim,
-    end_x: NcDim,
+    stylemask: NcStyle_u16,
+    channels: NcChannels_u64,
+    end_y: u32,
+    end_x: u32,
     boxmask: NcBoxMask,
-) -> NcIntResult {
+) -> NcResult_i32 {
     #[allow(unused_assignments)]
-    let mut ret = NcIntResult::OK;
+    let mut ret = NCRESULT_OK;
 
     let mut ul = NcCell::new();
     let mut ur = NcCell::new();
@@ -1092,8 +1115,19 @@ pub fn ncplane_rounded_box(
         ret = c_api::nccells_rounded_box(
             plane, stylemask, channels, &mut ul, &mut ur, &mut ll, &mut lr, &mut hl, &mut vl,
         );
-        if ret == NcIntResult::OK {
-            ret = c_api::ncplane_box(plane, &ul, &ur, &ll, &lr, &hl, &vl, end_y, end_x, boxmask);
+        if ret == NCRESULT_OK {
+            ret = c_api::ncplane_box(
+                plane,
+                &ul,
+                &ur,
+                &ll,
+                &lr,
+                &hl,
+                &vl,
+                end_y,
+                end_x,
+                boxmask.into(),
+            );
         }
         nccell_release(plane, &mut ul);
         nccell_release(plane, &mut ur);
@@ -1111,12 +1145,12 @@ pub fn ncplane_rounded_box(
 #[inline]
 pub fn ncplane_rounded_box_sized(
     plane: &mut NcPlane,
-    stylemask: NcStyle,
-    channels: NcChannels,
-    len_y: NcDim,
-    len_x: NcDim,
+    stylemask: NcStyle_u16,
+    channels: NcChannels_u64,
+    len_y: u32,
+    len_x: u32,
     boxmask: NcBoxMask,
-) -> NcIntResult {
+) -> NcResult_i32 {
     let (mut y, mut x) = (0, 0);
     unsafe {
         c_api::ncplane_cursor_yx(plane, &mut y, &mut x);
@@ -1125,8 +1159,8 @@ pub fn ncplane_rounded_box_sized(
         plane,
         stylemask,
         channels,
-        y as NcDim + len_y - 1,
-        x as NcDim + len_x - 1,
+        y as u32 + len_y - 1,
+        x as u32 + len_x - 1,
         boxmask,
     )
 }
@@ -1143,7 +1177,7 @@ pub fn ncplane_rounded_box_sized(
 /// go through the boundary of the plane in that axis (same as `0`).
 ///
 /// The glyph composed of `egc` and `stylemask` is used for all cells. The
-/// `NcChannels` specified by `ul`, `ur`, `ll`, and `lr` are composed into
+/// `NcChannels_u64` specified by `ul`, `ur`, `ll`, and `lr` are composed into
 /// foreground and background gradients.
 ///
 /// - To do a vertical gradient, `ul` ought equal `ur` and `ll` ought equal `lr`.
@@ -1165,17 +1199,17 @@ pub fn ncplane_rounded_box_sized(
 #[inline]
 pub fn ncplane_gradient(
     plane: &mut NcPlane,
-    y: Option<NcDim>,
-    x: Option<NcDim>,
-    len_y: Option<NcDim>,
-    len_x: Option<NcDim>,
+    y: Option<u32>,
+    x: Option<u32>,
+    len_y: Option<u32>,
+    len_x: Option<u32>,
     egc: &str,
-    stylemask: NcStyle,
-    ul: NcChannels,
-    ur: NcChannels,
-    ll: NcChannels,
-    lr: NcChannels,
-) -> NcIntResult {
+    stylemask: NcStyle_u16,
+    ul: NcChannels_u64,
+    ur: NcChannels_u64,
+    ll: NcChannels_u64,
+    lr: NcChannels_u64,
+) -> NcResult_i32 {
     #[cfg(any(target_arch = "armv7l", target_arch = "i686"))]
     let egc_ptr = cstring![egc] as *const i8;
     #[cfg(not(any(target_arch = "armv7l", target_arch = "i686")))]
@@ -1184,8 +1218,8 @@ pub fn ncplane_gradient(
     unsafe {
         c_api::ffi::ncplane_gradient(
             plane,
-            y.unwrap_or(NcDim::MAX) as i32,
-            x.unwrap_or(NcDim::MAX) as i32,
+            y.unwrap_or(u32::MAX) as i32,
+            x.unwrap_or(u32::MAX) as i32,
             len_y.unwrap_or(0),
             len_x.unwrap_or(0),
             egc_ptr,
@@ -1204,7 +1238,7 @@ pub fn ncplane_gradient(
 ///
 /// *Method: NcPlane.[gradient()][NcPlane#method.gradient].*
 #[inline]
-pub fn ncplane_cursor_y(plane: &NcPlane) -> NcDim {
+pub fn ncplane_cursor_y(plane: &NcPlane) -> u32 {
     let mut y = 0;
     unsafe {
         c_api::ncplane_cursor_yx(plane, &mut y, null_mut());
@@ -1216,7 +1250,7 @@ pub fn ncplane_cursor_y(plane: &NcPlane) -> NcDim {
 ///
 /// *Method: NcPlane.[gradient()][NcPlane#method.gradient].*
 #[inline]
-pub fn ncplane_cursor_x(plane: &NcPlane) -> NcDim {
+pub fn ncplane_cursor_x(plane: &NcPlane) -> u32 {
     let mut x = 0;
     unsafe {
         c_api::ncplane_cursor_yx(plane, null_mut(), &mut x);
