@@ -37,14 +37,14 @@
 //W+ ncvisualplane_create
 
 #[allow(unused_imports)] // for doc comments
-use crate::{NcBlitter, NcChannel, NcDim, NcOffset, NcPlane, NcRgb, NcScale};
+use crate::{NcBlitter, NcChannel, NcPlane, NcScale};
 
 mod geometry;
 mod methods;
 pub(crate) mod options;
 mod reimplemented;
 
-pub use geometry::{NcVGeom, NcVisualGeometry};
+pub use geometry::NcVisualGeometry;
 pub use options::{NcVisualOptions, NcVisualOptionsBuilder};
 
 /// A visual bit of multimedia.
@@ -55,35 +55,9 @@ pub use options::{NcVisualOptions, NcVisualOptionsBuilder};
 /// - [`geom`][NcVisual#method.geom]
 /// - [`render`][NcVisual#method.render]
 /// - [`simple_streamer`][NcVisual#method.simple_streamer]
-pub type NcVisual = crate::bindings::ffi::ncvisual;
+pub type NcVisual = crate::c_api::ffi::ncvisual;
 
-// NcRgba
-//
-/// Three RGB [`NcComponent`]s plus one alpha [`NcComponent`] (alias of `u32`).
-///
-/// ## Diagram
-///
-/// ```txt
-/// AAAAAAAA RRRRRRRR GGGGGGGG BBBBBBBB
-/// ```
-/// `type in C: no data type`
-///
-/// See also: [`NcRgb`] and [`NcChannel`] types.
-///
-/// [`NcComponent`]: crate::NcComponent
-pub type NcRgba = u32;
-
-// // NcBgra
-// //
-// /// 32 bits broken into 3x 8bpp BGR channels + 8ppp alpha.
-// ///
-// /// ## Diagram
-// ///
-// /// ```txt
-// /// AAAAAAAA BBBBBBBB GGGGGGGG RRRRRRRR
-// /// ```
-// ///
-// /// `type in C: no data type`
-// ///
-// /// See also: [`NcRgba`], [`NcRgb`] and [`NcChannel`] types.
-// pub type NcBgra = u32;
+pub(crate) mod c_api {
+    pub use super::geometry::c_api::*;
+    pub use super::options::c_api::*;
+}
